/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02391
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1996
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02391-0001-statasetup.do)
 |
 **************************************************************************/

set mem 60m  /* Allocating 60 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Household Survey on Drug Abuse, 1996, Dataset 0001"

#delimit ;
label define SKPMARTL  1 "Respondent is 12-14 years old - SKIP"
                       2 "Respondent is 15 years old or older"
                       3 "12-14 years old LOGICALLY ASSIGNED - SKI"
                       4 "15 years or older LOGICALLY ASSIGNED" ;
label define MARITAL   1 "Married" 2 "Widowed" 3 "Divorced or separated"
                       4 "Never been married"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NOMARR    85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPMILT   1 "Respondent is 12-16 years old - SKIP"
                       2 "Respondent is 17 years old or older"
                       3 "12-16 years old LOGICALLY ASSIGNED - SKI"
                       4 "17 years or older LOGICALLY ASSIGNED" ;
label define SERVICE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MILSTAT   2 "In a reserves component"
                       3 "Now separated or retired from reserves/a"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EDUC      0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "Freshman/13th year"
                       14 "Sophomore/14th year" 15 "Junior/15th year"
                       16 "Senior/16th year"
                       17 "Graduate/Professional School (or higher)"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DIPLOMA   1 "High School Diploma" 2 "GED Certificate"
                       3 "Neither of the above"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ENROLLD   1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a we"
                       2 "Working part-time, less than 35 hours a"
                       3 "Have a job but out: illness/leave/furlou"
                       4 "Have a job but it is seasonal"
                       5 "Unemployed or laid off and looking for w"
                       6 "Unemployed and not looking for work"
                       7 "Full-time homemaker" 8 "In school only" 9 "Retired"
                       10 "Disabled for work" 11 "Other, not specified"
                       21 "Working full-time, 35 hours or more a we"
                       22 "Working part-time, less than 35 hours a"
                       23 "Have a job but out: illness/leave/furlou"
                       24 "Have a job, but it is seasonal"
                       25 "Unemployed or laid off and looking for w"
                       27 "Full-time homemaker" 28 "In school only"
                       30 "Disabled for work" 31 "Other, in labor force"
                       32 "Other, not in the labor force"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HTININCH  985 "BAD DATA Logically assigned" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define POUNDS    985 "BAD DATA Logically assigned" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HEALTH    1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGTRY    981 "NEVER USED CIGARETTES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CIGTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIG30USE  35 "Date specified within the past 30 days"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       83 "DID NOT USE CIGARETTES IN PAST 30 DAYS L"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DA"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AVCIG     1 "At least a puff but less than one cig ea"
                       2 "1 to 5 cigarettes each day"
                       3 "6 to 15 cigarettes (about 1/2 pack) each"
                       4 "16 to 25 cigarettes (about 1 pack) each"
                       5 "26 to 35 cigarettes (about 1 1/2 pk) eac"
                       6 "35 or more cigarettes (about 2 packs) ea"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       83 "DID NOT USE CIGARETTES PAST 30 DAYS Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIG30WOK  1 "5 minutes or less" 2 "6 to 30 minutes"
                       3 "31 to 60 minutes" 4 "1 to 3 hours"
                       5 "4 or more hours"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       83 "DID NOT USE CIGARETTES IN PAST 30 DAYS L"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DA"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGEVYDA  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGAGE    981 "NEVER USED CIGARETTES Logically assigned"
                       983 "NEVER USED CIGARETTES EVERYDAY Log assn"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES"
                       993 "NEVER USED CIGARETTES EVERYDAY" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CIGYRS    0 "I smoked cigs every day but only for < o"
                       981 "NEVER USED CIGARETTES Logically assigned"
                       983 "NEVER USED CIGARETTES EVERYDAY Log assn"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES"
                       993 "NEVER USED CIGARETTES EVERYDAY" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SNUFEVER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SNUFREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED SMOKELESS TOBACCO Logically a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SKPALCRD  1 "Yes, respondent can complete the answer"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ALCREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define ALCTRY    981 "NEVER USED ALCOHOL Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL" 994 "DONT KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCPAT    1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo"
                       85 "BAD DATA Logically assigned"
                       90 "HAD A DRINK BUT DID NOT GET DRUNK PST 12"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCDAYS   81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define NODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define DR5DAY    0 "No days" 81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT DRINK ALCOHOL IN PAST 30 DAYS Lo"
                       85 "BAD DATA Logically assigned"
                       90 "HAD A DRINK BUT NEVER MORE THAN 5 PAST 3"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJEVER    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define MJAGE     981 "NEVER USED MARIJUANA Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DONT KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       91 "NEVER USED MARIJUANA" ;
label define MJYRFREQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJDAY30A  81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA IN THE PAST 30 DAY"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 30 DAY"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define SKPCOCRD  1 "Yes, respondent can complete the answer"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COCREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define COCAGE    981 "NEVER USED COCAINE Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)" ;
label define COCTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       91 "NEVER USED COCAINE" ;
label define COCYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MONTHS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCUS30A  81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN THE PAST 30 DAYS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 30 DAYS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define SKPCRKRD  1 "Yes, respondent can complete answer shee"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define CRKREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRKEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 98 "BLANK (NO ANSWER)" ;
label define CRKAGE    981 "NEVER USED CRACK Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)" ;
label define CRKTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED CRACK Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED CRACK Logically assigned"
                       91 "NEVER USED CRACK" 98 "BLANK (NO ANSWER)" ;
label define CRKYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PAST 12 MONTHS Log a"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MONTH"
                       98 "BLANK (NO ANSWER)" ;
label define CRKUS30A  81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK IN THE PAST 30 DAYS"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 30 DAYS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define SKPHERRD  1 "Yes, respondent can complete answer shee"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HEREVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERAGE    981 "NEVER USED HEROIN Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN PAST 12 MONTHS Log as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 12 MONTHS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HER30USE  81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN IN PAST 30 DAYS Log a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPHALRD  1 "Yes, respondent can complete answer shee"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define HALREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSD       1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (LSDREC=1,2,3,4 o"
                       4 "No LOGICALLY ASSIGNED (LSDREC=81 or 91)"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (PCPREC=1,2,3,4 o"
                       4 "No LOGICALLY ASSIGNED (PCPREC=81 or 91)"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Yes" 2 "No"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Yes" 2 "No"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PSILCY    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Yes" 2 "No"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALNEWA   116 "Methaqualone, Parest, Quaalude, Sopor" 129 "Reds"
                       142 "Belladona" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       327 "Black beauties, Black Beauty" 336 "Diet pills"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 501 "Gasoline or lighter fluids"
                       506 "Amyl nitrate, poppers, locker room odo"
                       508 "Nitrous oxide, whippets, dentist gas"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       520 "Old paint, paint"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms), shooms"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       610 "Crystal T" 614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds" 636 "STP"
                       639 "Cloves, Nutmeg" 690 "RID" 691 "Maximum impact"
                       692 "sic" 693 "Lemon drops" 694 "sic" 695 "sic"
                       697 "sic" 703 "Opium" 801 "OTHER Drugs, NOT SPECIFIED"
                       802 "THC, cannabinol" 803 "sic" 814 "Caffeine"
                       829 "Robitussin DM" 857 "sic"
                       864 "Dramamine <OTC>, Motion sickness pill <O"
                       3009 "CAT, Ephedrone, Methcathinone"
                       6001 "Collapsing little birds" 6002 "sic"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define HALNEWB   110 "Tuinal, rainbows"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       305 "Biphetamine" 348 "Crystal" 459 "Ketamine"
                       502 "Spray paints" 639 "Cloves, Nutmeg"
                       658 "Special K" 696 "sic" 698 "Nexus, 2C-B"
                       802 "THC, cannabinol"
                       864 "Dramamine <OTC>, Motion sickness pill <O"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define HALNEWC   201 "Valium" 267 "Marezine" 328 "Pink hearts"
                       401 "Darvon" 614 "MDA, Methylenedioxy amphetamine"
                       617 "Morning glory seeds" 699 "BOHA-49B"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define HALNEWD   142 "Belladona" 9991 "NEVER USED HALLUCINOGENS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALNEWE   689 "sic" 9991 "NEVER USED HALLUCINOGENS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALLAGE   981 "NEVER USED HALLUCINOGENS Logically assig"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALLREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALYRFRQ  1 "More than 300 days (every day/almost eve"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than 1 day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       83 "DID NOT USE HALLUCINOGENS PST 12 MOS Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HAL30USE  81 "NEVER USED HALLUCINOGENS Logically assig"
                       83 "DID NOT USE HALLUCINOGENS IN PAST 30 DAY"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED LSD Logically assigned"
                       91 "NEVER USED LSD" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED PCP Logically assigned"
                       91 "NEVER USED PCP" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SKPINHRD  1 "Yes, respondent can complete the answer"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define INHREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AMYLNIT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CLEFLU    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GAS       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LGAS      1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHNEWA   112 "Rasepam, Restoril, Temaz, Temazepam"
                       304 "Benzedrine"
                       322 "Methamphetamine (speed or ice or cr" 419 "Stadol"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       506 "Amyl nitrate, poppers, locker room odo"
                       507 "Halothane, ether, or other anesthetics;"
                       509 "Corr flds, degreasers, cleaning flds, Li"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 516 "Freon"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       520 "Old paint, paint" 523 "Matches"
                       524 "see also 509" 526 "Nail polish"
                       528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial d"
                       539 "ScotchGard" 540 "PAM" 543 "Liquid oxygen"
                       545 "Car tailpipe exhaust fumes, CO2"
                       548 "Cologne, isopropanol vapors, rubbing alc"
                       580 "sic" 585 "TCL"
                       586 "Carbon from empty softdrink bottle"
                       587 "Mineral ice" 691 "Maximum impact" 803 "sic"
                       809 "Pills"
                       9981 "NEVER USED INHALANTS Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define INHNEWB   501 "Gasoline or lighter fluids"
                       509 "Corr flds, degreasers, cleaning flds, Li"
                       524 "see also 509" 9991 "NEVER USED INHALANTS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define INHNEWC   504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define INHNEWD   504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define INHNEWE   504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define INHAGE    981 "NEVER USED INHALANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INHTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHDY30A  81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS IN THE PAST 30 DAY"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 30 DAY"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPANLRD  1 "Yes, respondent can complete answer shee"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ANLREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CODEINE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Yes" 2 "No"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANLNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  116 "Methaqualone, Parest, Quaalude, Sopor" 129 "Reds"
                       135 "Mini Thins" 157 "Barbituates"
                       161 "Rohypnol, Roofies, Rope, Roples, Rufinal"
                       201 "Valium" 209 "Xanax"
                       234 "Cyclobenzaprine, Flexeril" 275 "Loxitane"
                       318 "Ritalin, Methylphenidate" 403 "SK-65"
                       407 "Demerol"
                       410 "Phenaphen with Codeine, Phenaphen 3" 411 "Talwin"
                       414 "Propoxyphene" 415 "Codeine" 419 "Stadol"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DONT KNOW NAME" 422 "Motrin"
                       423 "Percocet" 424 "Fioricet"
                       426 "Butalbital, Esgic, Fiorinal, Phrenilin F"
                       427 "Darvocet" 430 "Aspirin, Ecotrin, Empirin <OTC>"
                       431 "Tylox"
                       434 "Anexia, Co-Gesic, Hydrocodone, Lortab, e"
                       435 "Tylenol, Tylenol Extra Strength <OTC>"
                       436 "Bufferin <OTC>" 438 "Anaprox, Naprosyn"
                       440 "Soma" 442 "Ibuprofen"
                       456 "Lorcet HD, Lorcet Plus, Lortab [see also"
                       465 "Fentanyl" 491 "PDR" 492 "sic" 493 "IBU"
                       496 "Tramadol, Ultram" 497 "sic"
                       498 "Ponstel, Mefenamic acid"
                       821 "Amoxicillin, Ampicillin"
                       840 "Cough medicine (contents not specified)"
                       864 "Dramamine <OTC>, Motion sickness pill <O"
                       895 "Tagamet, Cimetidine"
                       9991 "NEVER USED PAIN KILLERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       161 "Rohypnol, Roofies, Rope, Roples, Rufinal"
                       201 "Valium" 209 "Xanax"
                       234 "Cyclobenzaprine, Flexeril"
                       240 "Lithium carbonate" 326 "White cross"
                       406 "Oxycodone, Percodan, Roxicet" 419 "Stadol"
                       423 "Percocet" 427 "Darvocet"
                       430 "Aspirin, Ecotrin, Empirin <OTC>" 431 "Tylox"
                       434 "Anexia, Co-Gesic, Hydrocodone, Lortab, e"
                       438 "Anaprox, Naprosyn" 896 "Catapres, Clonidine"
                       9991 "NEVER USED PAIN KILLERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define ANALNEWC  115 "Phenobarbital" 129 "Reds" 206 "Tranxene"
                       227 "Thorazine" 407 "Demerol" 423 "Percocet"
                       427 "Darvocet"
                       434 "Anexia, Co-Gesic, Hydrocodone, Lortab, e"
                       495 "Red cross" 9991 "NEVER USED PAIN KILLERS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define ANALNEWD  110 "Tuinal, rainbows" 201 "Valium"
                       406 "Oxycodone, Percodan, Roxicet" 415 "Codeine"
                       426 "Butalbital, Esgic, Fiorinal, Phrenilin F"
                       9991 "NEVER USED PAIN KILLERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define ANALNEWE  9991 "NEVER USED PAIN KILLERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANALAGE   981 "NEVER USED PAIN KILLERS Logically assign"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED PAIN KILLERS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       91 "NEVER USED PAIN KILLERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANLYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED PAIN KILLERS Logically assign"
                       83 "DID NOT USE PAIN KILLERS IN PST 12 MONTH"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN KILLERS"
                       93 "DID NOT USE PAIN KILLERS IN THE PAST 12"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPTRNRD  1 "Yes, I think resp can complete answer sh"
                       2 "No, I doubt that resp. can complt. it al"
                       98 "BLANK (NO ANSWER)" ;
label define TRNREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ATARAX    1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNOLST   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor" 129 "Reds"
                       131 "Haldol, Haloperidol"
                       161 "Rohypnol, Roofies, Rope, Roples, Rufinal"
                       201 "Valium" 205 "Serax" 208 "Centrax" 209 "Xanax"
                       211 "Buspar" 213 "Equanil"
                       220 "Meprobamate, Meprospan"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DONT KNOW NAME"
                       239 "see also 228" 246 "Clonopin, Klonopin"
                       271 "Zoloft" 422 "Motrin"
                       434 "Anexia, Co-Gesic, Hydrocodone, Lortab, e"
                       440 "Soma" 491 "PDR" 658 "Special K"
                       9991 "NEVER USED TRANQUILIZERS"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWB    116 "Methaqualone, Parest, Quaalude, Sopor"
                       161 "Rohypnol, Roofies, Rope, Roples, Rufinal"
                       419 "Stadol"
                       456 "Lorcet HD, Lorcet Plus, Lortab [see also"
                       9991 "NEVER USED TRANQUILIZERS"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWC    494 "sic" 9991 "NEVER USED TRANQUILIZERS"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWD    431 "Tylox" 9991 "NEVER USED TRANQUILIZERS"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWE    9991 "NEVER USED TRANQUILIZERS"
                       9998 "BLANK (NO ANSWER)" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       98 "BLANK (NO ANSWER)" ;
label define TRANAGE   981 "NEVER USED TRANQUILIZERS Logically assig"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       83 "DID NOT USE TRANQUILIZERS PAST 12 MOS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12"
                       98 "BLANK (NO ANSWER)" ;
label define SKPSTMRD  1 "Yes, I think respondent can complete it"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define STMREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BENZ      1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STMNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  135 "Mini Thins"
                       306 "Desoxyn, Methamphetamine hydrochloride"
                       307 "Tenuate, Diethylpropion" 315 "Voranil"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       322 "Methamphetamine (speed or ice or cr"
                       325 "USED STIMULANT, DONT KNOW NAME" 326 "White cross"
                       327 "Black beauties, Black Beauty" 328 "Pink hearts"
                       329 "Bird eggs, robins eggs, speckled eggs"
                       331 "Blancas, Whites" 332 "see also 346"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops" 336 "Diet pills"
                       339 "Amphetamines (speed generically)"
                       345 "Black Molly" 348 "Crystal" 353 "No-Doz <OTC>"
                       354 "Vivarin <OTC>" 364 "Sinutab, Sudafed {OTC}"
                       377 "Ventolin" 606 "sic" 658 "Special K"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       814 "Caffeine" 815 "Coffee" 898 "Propylene"
                       3001 "Brown and clear" 3007 "Nasal inhalant"
                       3008 "Miniwhites" 3010 "KOOD12" 3011 "Escalation"
                       9900 "NOT A DRUG" 9991 "NEVER USED STIMULANTS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  135 "Mini Thins" 317 "Mazanor"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       329 "Bird eggs, robins eggs, speckled eggs"
                       330 "Blue birds, blue jays, blue robins, spec"
                       331 "Blancas, Whites" 333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)"
                       353 "No-Doz <OTC>" 364 "Sinutab, Sudafed {OTC}"
                       3006 "Green Amps" 9991 "NEVER USED STIMULANTS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  326 "White cross" 327 "Black beauties, Black Beauty"
                       332 "see also 346" 814 "Caffeine"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  336 "Diet pills" 9991 "NEVER USED STIMULANTS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWE  9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STIMAGE   981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STMYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MO"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPSEDRD  1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SEDREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DALMANE   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   105 "Placidyl" 111 "Dalmane, Durapam"
                       114 "Amobarbital"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       121 "USED SEDATIVE, DONT KNOW NAME" 129 "Reds"
                       138 "sic"
                       161 "Rohypnol, Roofies, Rope, Roples, Rufinal"
                       201 "Valium" 227 "Thorazine" 275 "Loxitane"
                       326 "White cross" 362 "Benadryl"
                       435 "Tylenol, Tylenol Extra Strength <OTC>" 440 "Soma"
                       468 "Excedrin <OTC>"
                       843 "Antihistamine, cold tablets <OTC>"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   110 "Tuinal, rainbows" 115 "Phenobarbital" 170 "sic"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SEDNEWC   9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SEDNEWD   9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SEDNEWE   9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDAGE    981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDYRFRQ  1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       83 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BIRMONTH  98 "BLANK (NO ANSWER)" ;
label define BIRYEAR   9998 "BLANK (NO ANSWER)" ;
label define IIAGE     1 "Age from birthdate"
                       2 "Age from cover of questionnaire"
                       3 "Age from roster"
                       4 "Age statistically imputed using age gr f" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire"
                       2 "Sex from relationship on roster"
                       3 "Sex from roster" ;
label define IRRACE    1 "American Indian or Alaskan native"
                       2 "Asian or Pacific islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Race from questionnaire"
                       2 "Race from interview observation"
                       3 "Race from roster"
                       4 "Race status imputed using race - Other" ;
label define IRHOIND   1 "Hispanic" 2 "Nonhispanic" ;
label define IIHOIND   1 "Hispanicity derived from questionnaire"
                       2 "Hispanicity derived from roster" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       99 "LEGITIMATE SKIP" ;
label define IIHOGRP   1 "Hispanic-Origin Group taken from questio"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispan" ;
label define IRHOGRP2  1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       5 "Central American" 6 "South American" 7 "Caribbean"
                       99 "LEGITIMATE SKIP Respondent is not hispan" ;
label define IIHOGRP2  1 "Hispanic-Origin Group taken from questio"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispan" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Questionnaire data" 3 "Statistically imputed data"
                       4 "Logically imputed data from roster"
                       5 "Statistically imputed data"
                       9 "LEGITIMATE SKIP (less than or = 14 years" ;
label define IREDUC    0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "Freshman/13th year"
                       14 "Sophomore/14th year" 15 "Junior/15th year"
                       16 "Senior/16th year"
                       17 "Graduate/Professional School (or higher)" ;
label define IIEDUC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHSGRAD  1 "Yes, graduated from high school"
                       2 "No, did not graduate from high school" ;
label define IIHSGRAD  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWORKST  1 "Working full-time, 35 hours or more a we"
                       2 "Working part-time, less than 35 hours a"
                       3 "Have a job, but not at work, illness/mat"
                       4 "Have a job but not at work b/c it is sea"
                       5 "Unemployed or laid off and looking for w"
                       6 "Unemployed or laid off and not looking f"
                       7 "Full-time homemaker" 8 "In school only" 9 "Retired"
                       10 "Disabled for work" 11 "Other, in labor force"
                       12 "Other, not in labor force" ;
label define IIWORKST  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRCIGRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Never used smokeless tobacco" ;
label define IIOTBRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRALCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJRC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCRKRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used crack" ;
label define IICRKRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHERRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRLSDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used LSD" ;
label define IILSDRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPCPRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINHRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used analgesics" ;
label define IIANLRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRTRNRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSTMRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSEDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRALCFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJFQ    1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCRKFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week past year"
                       3 "Used 3-4 days per week past year"
                       4 "Used 1-2 days per week past year"
                       5 "Used 3-4 days per month past year"
                       6 "Used 1-2 days per month past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IICRKFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHERFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IIHERFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IIHALFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRINHFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IIINHFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IIANLFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRTRNFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IITRNFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTMFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IISTMFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDFQ   1 "Used daily in past year"
                       2 "Used 5-6 days per week in past year"
                       3 "Used 3-4 days per week in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used 3-4 days per month in past year"
                       6 "Used 1-2 days per month in past year"
                       7 "Used less than one day per month in past"
                       8 "Used 3-5 days in past 12 months"
                       9 "Used 1-2 days in past 12 months"
                       10 "Never used or did not use in the past ye" ;
label define IISEDFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define CATAGE    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35+ years" ;
label define CATAG2    1 "12-17 years" 2 "18-25 years" 3 "26+ years" ;
label define CATAG3    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35-49 years" 5 "50+ years" ;
label define RACE      1 "White (IRRACE = 4 and IRHOIND = 2)"
                       2 "Black (IRRACE = 3 and IRHOIND = 2)"
                       3 "Hispanic (IRHOIND = 1)"
                       4 "Other (IRRACE = 1-2 and IRHOIND = 2)" ;
label define HISPRACE  1 "Hispanic" 2 "Nonhispanic Black"
                       3 "Nonhispanic Nonblack" ;
label define EDUCCAT2  1 "Less than high school (IREDUC=0-11 and I"
                       2 "High school graduate (IREDUC = 12 and IR"
                       3 "Some college (IREDUC = 13-15 and IRAGE ="
                       4 "College graduate (IREDUC = 16-17 and IRA"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define EMPSTAT2  1 "Full=time (IRWORKST = 1,3 and IRAGE => 1"
                       2 "Part-time (IRWORKST = 2 and IRAGE => 18)"
                       3 "Unemployed (IRWORKST = 4,5,6,11 and IRAG"
                       4 "Other (IRWORKST = 7,8,9,10,12 and IRAGE"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define MARISTAT  1 "Married (IRMARIT=1)"
                       2 "Not Married (IRMARIT=2,3,4)"
                       3 "LEGITIMATE SKIP (IRMARIT=99)" ;
label define NOTMAR    1 "Never Married (IRMARIT=4)"
                       2 "Divorced/Separated or Widowed (IRMARIT=2"
                       3 "Married/Legitimate Skip (IRMARIT=1,99)" ;
label define CIGFLAG   0 "Never used (IRCIGRC = 9)"
                       1 "Ever used (IRCIGRC = 1-4)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC ="
                       1 "Used within the past year (IRCIGRC = 1,2" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC ="
                       1 "Used within the past month (IRCIGRC = 1)" ;
label define SMKFLAG   0 "Never used (IROTBRC = 9)"
                       1 "Ever used (IROTBRC = 1-4)" ;
label define SMKYR     0 "Did not use in the past year (IROTBRC ="
                       1 "Used within the past year (IROTBRC = 1,2" ;
label define SMKMON    0 "Did not use in the past month (IROTBRC ="
                       1 "Used within the past month (IROTBRC = 1)" ;
label define ALCFLAG   0 "Never used (IRALCRC = 9)"
                       1 "Ever used (IRALCRC = 1-4)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC ="
                       1 "Used within the past year (IRALCRC = 1,2" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC ="
                       1 "Used within the past month (IRALCRC = 1)" ;
label define MRJFLAG   0 "Never used (IRMJRC = 9)"
                       1 "Ever used (IRMJRC = 1-4)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC = 3"
                       1 "Used within the past year (IRMJRC = 1,2)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC ="
                       1 "Used within the past month (IRMJRC = 1)" ;
label define COCFLAG   0 "Never used (IRCOCRC = 9)"
                       1 "Ever used (IRCOCRC = 1-4)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC ="
                       1 "Used within the past year (IRCOCRC = 1,2" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC ="
                       1 "Used within the past month (IRCOCRC = 1)" ;
label define CRKFLAG   0 "Never used (IRCRKRC = 9)"
                       1 "Ever used (IRCRKRC = 1-4)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKRC= 3"
                       1 "Used within the past year (IRCRKRC = 1,2" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC ="
                       1 "Used within the past month (IRCRKRC = 1)" ;
label define HERFLAG   0 "Never used (IRHERRC = 9)"
                       1 "Ever used (IRHERRC = 1-4)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC ="
                       1 "Used within the past year (IRHERRC = 1,2" ;
label define HERMON    0 "Did not use in the past month (IRHERRC ="
                       1 "Used within the past month (IRHERRC = 1)" ;
label define HALFLAG   0 "Never used (IRHALRC = 9)"
                       1 "Ever used (IRHALRC = 1-4)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC ="
                       1 "Used within the past year (IRHALRC = 1,2" ;
label define HALMON    0 "Did not use in the past month (IRHALRC ="
                       1 "Used within the past month (IRHALRC = 1)" ;
label define LSDFLAG   0 "Never used (IRLSDRC = 9)"
                       1 "Ever used (IRLSDRC = 1-4)" ;
label define LSDYR     0 "Did not use in the past year (IRLSDRC ="
                       1 "Used within the past year (IRLSDRC = 1,2" ;
label define LSDMON    0 "Did not use in the past month (IRLSDRC ="
                       1 "Used within the past month (IRLSDRC = 1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC = 9)"
                       1 "Ever used (IRPCPRC = 1-4)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC ="
                       1 "Used within the past year (IRPCPRC = 1,2" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC ="
                       1 "Used within the past month (IRPCPRC = 1)" ;
label define INHFLAG   0 "Never used (IRINHRC = 9)"
                       1 "Ever used (IRINHRC = 1-4)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC ="
                       1 "Used within the past year (IRINHRC = 1,2" ;
label define INHMON    0 "Did not use in the past month (IRINHRC ="
                       1 "Used within the past month (IRINHRC = 1)" ;
label define ANLFLAG   0 "Never used (IRANLRC = 9)"
                       1 "Ever used (IRANLRC = 1-4)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC ="
                       1 "Used within the past year (IRANLRC = 1,2" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC ="
                       1 "Used within the past month (IRANLRC = 1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC = 9)"
                       1 "Ever used (IRTRNRC = 1-4)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC ="
                       1 "Used within the past year (IRTRNRC = 1,2" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC ="
                       1 "Used within the past month (IRTRNRC = 1)" ;
label define STMFLAG   0 "Never used (IRSTMRC = 9)"
                       1 "Ever used (IRSTMRC = 1-4)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC ="
                       1 "Used within the past year (IRSTMRC = 1,2" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC ="
                       1 "Used within the past month (IRSTMRC = 1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC = 9)"
                       1 "Ever used (IRSEDRC = 1-4)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC ="
                       1 "Used within the past year (IRSEDRC = 1,2" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC ="
                       1 "Used within the past month (IRSEDRC = 1)" ;
label define ALCYRF    0 "Never used or not used in past year (IRA"
                       1 "Any use within the past year (IRALCFQ=1-" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRAL"
                       1 "Used monthly or more often past year (IR" ;
label define ALCWKF    0 "Did not use weekly or more pst year (IRA"
                       1 "Used weekly or more in past year (IRALCF" ;
label define ALCOCCF   0 "Used monthly/more or none pst yr (IRALCF"
                       1 "Used past year but less than monthly (IR" ;
label define ALCDLYF   0 "Did not use daily/almost dly pst yr(IRAL"
                       1 "Used daily/almost daily in past year (IR" ;
label define MRJYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRMJFQ=1-9" ;
label define MRJMONF   0 "Did not use monthly/more past year (IRMJ"
                       1 "Used monthly or more in past year (IRMJF" ;
label define MRJWKF    0 "Did not use weekly/more past year (IRMJF"
                       1 "Used weekly or more in past year (IRMJFQ" ;
label define MRJOCCF   0 "Used monthly/more or none in pst yr(IRMJ"
                       1 "Used past year but less than monthly (IR" ;
label define MRJDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define COCYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRCOCFQ =" ;
label define COCMONF   0 "Did not use monthly/more past year (IRCO"
                       1 "Used monthly or more often past year (IR" ;
label define COCWKF    0 "Did not use weekly or more pst year (IRC"
                       1 "Used weekly or more often past year (IRC" ;
label define COCOCCF   0 "Used monthly/more or none in pst yr(IRCO"
                       1 "Used past year but less than monthly (IR" ;
label define COCDLYF   0 "Did not use daily/almost dly pst yr(IRCO"
                       1 "Used daily/almost daily in past year (IR" ;
label define CRKYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRCRKFQ =" ;
label define CRKMONF   0 "Did not use monthly/more past year (IRCR"
                       1 "Used monthly or more often past year (IR" ;
label define CRKWKF    0 "Did not use weekly or more pst year (IRC"
                       1 "Used weekly or more often past year (IRC" ;
label define CRKOCCF   0 "Used monthly/more or none in pst yr(IRCR"
                       1 "Used past year but less than monthly (IR" ;
label define CRKDLYF   0 "Did not use daily/almost dly pst yr(IRCR"
                       1 "Used daily/almost daily in past year (IR" ;
label define HERYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRHERFQ=1-" ;
label define HERMONF   0 "Did not use monthly/more past year (IRHE"
                       1 "Used monthly or more often past year (IR" ;
label define HERWKF    0 "Did not use weekly or more pst year (IRH"
                       1 "Used weekly or more often past year (IRH" ;
label define HEROCCF   0 "Used monthly/more or none pst yr(IRHERFQ"
                       1 "Used past year but less than monthly (IR" ;
label define HERDLYF   0 "Did not use daily/almost daly pst yr(IRH"
                       1 "Used daily/almost daily in past year (IR" ;
label define HALYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRHALFQ=1-" ;
label define HALMONF   0 "Did not use monthly/more past year (IRHA"
                       1 "Used monthly or more often past year (IR" ;
label define HALWKF    0 "Did not use weekly or more pst year (IRH"
                       1 "Used weekly or more often past year (IRH" ;
label define HALOCCF   0 "Used monthly/more or none pst yr(IRHALFQ"
                       1 "Used past year but less than monthly (IR" ;
label define HALDLYF   0 "Did not use daily/almost dly pst yr(IRHA"
                       1 "Used daily/almost daily in past year (IR" ;
label define INHYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRINHFQ=1-" ;
label define INHMONF   0 "Did not use monthly/more past year (IRIN"
                       1 "Used monthly or more often past year (IR" ;
label define INHWKF    0 "Did not use weekly or more pst year (IRI"
                       1 "Used weekly or more often past year (IRI" ;
label define INHOCCF   0 "Used monthly/more or none pst yr(IRINHFQ"
                       1 "Used past year but less than monthly (IR" ;
label define INHDLYF   0 "Did not use daily/almost dly pst yr(IRIN"
                       1 "Used daily/almost daily in past year (IR" ;
label define ANLYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRANLFQ=1-" ;
label define ANLMONF   0 "Did not use monthly/more past year (IRAN"
                       1 "Used monthly or more often past year (IR" ;
label define ANLWKF    0 "Did not use weekly or more pst year (IRA"
                       1 "Used weekly or more often past year (IRA" ;
label define ANLOCCF   0 "Used monthly/more or none pst yr(IRANLFQ"
                       1 "Used past year but less than monthly (IR" ;
label define ANLDLYF   0 "Did not use daily/almost dly pst yr(IRAN"
                       1 "Used daily/almost daily in past year (IR" ;
label define TRQYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRTRNFQ=1-" ;
label define TRQMONF   0 "Did not use monthly/more past year (IRTR"
                       1 "Used monthly or more often past year (IR" ;
label define TRQWKF    0 "Did not use weekly or more pst year (IRT"
                       1 "Used weekly or more often past year (IRT" ;
label define TRQOCCF   0 "Used monthly/more or none pst yr(IRTRNFQ"
                       1 "Used past year but less than monthly (IR" ;
label define TRQDLYF   0 "Did not use daily/almost dly pst yr(IRTR"
                       1 "Used daily/almost daily in past year (IR" ;
label define STMYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRSTMFQ=1-" ;
label define STMMONF   0 "Did not use monthly/more past year (IRST"
                       1 "Used monthly or more often past year (IR" ;
label define STMWKF    0 "Did not use weekly or more pst year (IRS"
                       1 "Used weekly or more often past year (IRS" ;
label define STMOCCF   0 "Used monthly/more or none in pst yr(IRST"
                       1 "Used past year but less than monthly (IR" ;
label define STMDLYF   0 "Did not use daily/almost dly pst yr(IRST"
                       1 "Used daily/almost daily in past year (IR" ;
label define SEDYRF    0 "Never used or did not use in pst year (I"
                       1 "Any use within the past year (IRSEDFQ=1-" ;
label define SEDMONF   0 "Did not use monthly/more past year (IRSE"
                       1 "Used monthly or more often past year (IR" ;
label define SEDWKF    0 "Did not use weekly or more pst year (IRS"
                       1 "Used weekly or more often past year (IRS" ;
label define SEDOCCF   0 "Used monthly/more or none pst yr(IRSEDFQ"
                       1 "Used past year but less than monthly (IR" ;
label define SEDDLYF   0 "Did not use daily/almost dly pst yr(IRSE"
                       1 "Used daily/almost daily in past year (IR" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES = 9)"
                       1 "Ever used (ANY SOURCE VARIABLE < 9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE"
                       1 "Used in past year (ANY SOURCE VARIABLE <" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES = 0)"
                       1 "Ever used (ANY SOURCE VARIABLE = 1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VAR"
                       1 "Used in past year (ANY SOURCE VARIABLE =" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anothr"
                       1 "Marijuana is only (illicit) drug ever us" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug"
                       1 "Marijuana is only (illicit) drug in past" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr dr"
                       1 "Marijuana only (illicit) drug in past mo" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ev" ;
label define IEMYR     0 "Never used drug/used only marijuana past"
                       1 "Illicit drug except for marijuana used p" ;
label define IEMMON    0 "Never used drug/used only marijuana past"
                       1 "Illicit drug except for marijuana used p" ;
label define BINGEDRK  0 "Never/No Binge ALC use (DR5DAY=0,81,83"
                       1 "Binge alcohol use (DR5DAY = 1-30)"
                       99 "Unknown (DR5DAY = 85,94,95,98)" ;
label define HVYDRK2   0 "Never/No heavy ALC use(DR5DAY=0-4,81,83,"
                       1 "Heavy alcohol use (DR5DAY = 5-30)"
                       99 "Unknown (DR5DAY = 85,94,95,98)" ;
label define BINGEHVY  1 "Heavy alcohol use"
                       2 "Binge alcohol use but not heavy use"
                       3 "Past 30 day alcohol use but not binge"
                       4 "Did not use alcohol in the past 30 days"
                       99 "Unknown" ;
label define PEYOTE2   0 "No/Unknown (PEYOTE=2,81,91,94,97,98)"
                       1 "Yes (PEYOTE=1)" ;
label define MESC2     0 "No/Unknown (MESC=2,81,91,94,97,98)"
                       1 "Yes (MESC=1)" ;
label define PSILCY2   0 "No/Unknown (PSILCY=2,81,91,94,97,98)"
                       1 "Yes (PSILCY=1,3)" ;
label define ECSTASY2  0 "No/Unknown (ECSTASY=2,81,91,94,97,98)"
                       1 "Yes (ECSTASY=1)" ;
label define METHAMP2  0 "No/Unknown (METHAMP=2,81,91,97,98)"
                       1 "Yes (METHAMP=1,3)" ;
label define HERSMOK2  0 "No/Unknown (HERSMOKE=2,85,89,97,98,99)"
                       1 "Yes (HERSMOKE=1,3)" ;
label define HERSNIF2  0 "No/Unknown (HERSNIFF=2,4,85,89,97,98,99)"
                       1 "Yes (HERSNIFF=1,3)" ;
label define AMYLNIT2  0 "No/Unknown (AMYLNIT=2,81,91,97,98)"
                       1 "Yes (AMYLNIT=1,3)" ;
label define CLEFLU2   0 "No/Unknown (CLEFLU=2,81,91,97,98)"
                       1 "Yes (CLEFLU=1,3)" ;
label define GAS2      0 "No/Unknown (GAS=2,81,91,97,98)" 1 "Yes (GAS=1,3)" ;
label define GLUE2     0 "No/Unknown (GLUE=2,81,91,97,98)" 1 "Yes (GLUE=1,3)" ;
label define ETHER2    0 "No/Unknown (ETHER=2,81,91,97,98)"
                       1 "Yes (ETHER=1,3)" ;
label define SOLVENT2  0 "No/Unknown (SOLVENT=2,81,91,97,98)"
                       1 "Yes (SOLVENT=1)" ;
label define LGAS2     0 "No/Unknown (LGAS=2,81,91,97,98)" 1 "Yes (LGAS=1)" ;
label define NITOXID2  0 "No/Unknown (NITOXID=2,81,91,97,98)"
                       1 "Yes (NITOXID=1)" ;
label define SPPAINT2  0 "No/Unknown (SPPAINT=2,81,91,97,98)"
                       1 "Yes (SPPAINT=1,3)" ;
label define AEROS2    0 "No/Unknown (AEROS=2,81,91,97,98)"
                       1 "Yes (AEROS=1,3)" ;
label define CG04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG12      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AL03      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 98 "BLANK (NO ANSWER)" ;
label define AL04      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       98 "BLANK (NO ANSWER)" ;
label define MJ04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 98 "BLANK (NO ANSWER)" ;
label define MJ05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define CC04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 98 "BLANK (NO ANSWER)" ;
label define CC05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MONTH"
                       98 "BLANK (NO ANSWER)" ;
label define CK04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       98 "BLANK (NO ANSWER)" ;
label define CK05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MONTH"
                       98 "BLANK (NO ANSWER)" ;
label define HE04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HE05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 12 MONTHS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LS05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS07      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED LSD"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS08      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED PCP"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define IN04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IN05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PK04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PK05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       93 "DID NOT USE PAIN KILLERS IN THE PAST 12"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TR05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ST05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MO"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SE04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SE05      1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       85 "BAD DATA Logically assigned"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPSDRD   1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SDREAD    1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HRANYFRM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERSMOKE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRAN"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM = 2, 4)" ;
label define HRSMKREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       83 "USED HEROIN BUT NEVER SMOKED IT Logicall"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRAN"
                       93 "USED HEROIN BUT NEVER SMOKED IT" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM = 2, 4)" ;
label define HERSNIFF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRAN"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM = 2, 4)" ;
label define HRSNFREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       83 "USED HEROIN BUT NEVER SNIFFED IT Log ass"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRAN"
                       93 "USED HEROIN BUT NEVER SNIFFED IT" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM = 2, 4)" ;
label define GNNDLLIF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COCNEEDL  1 "Yes" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define CONDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "USED COCAINE BUT NEVER WITH A NEEDLE Log"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define HERNEEDL  1 "Yes" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define HRNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define STNEEDLE  1 "Yes" 3 "Yes LOGICALLY ASSIGNED"
                       83 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       91 "NEVER USED STIMULANTS"
                       93 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define STNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       91 "NEVER USED STIMULANTS"
                       93 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDREUS  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDLSH1  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDCLEN  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDLSH2  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDGET   1 "I bought the needle from a pharmacy"
                       2 "I got the needle from a needle exchange"
                       3 "I bought the needle on the street"
                       4 "I got the needle in a shooting gallery"
                       5 "I got the needle some other way"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNND"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDGTSP  6 "Given by, stolen from a friend"
                       8 "Given by, stolen from someone, relation"
                       13 "I bought the needle on the street"
                       15 "Given by, stolen from medical facility/p"
                       16 "Given by, stolen from work"
                       17 "Given by, stolen from a pharmacy"
                       18 "Bought, given, stolen from place/locatio"
                       19 "Homemade/self-made needle" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define SKPRSKRD  1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define RSKREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK5DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKBINGE  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 95 "BAD DATA"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKDIFMJ  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFCOC  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFCRK  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFHER  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKSELL   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPDRGRD  1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define DRGREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define USEDCIG   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDMRJ   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDHER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDINH   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDANL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDTRN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDSTM   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDSED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NODRUGYR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define GRTMSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define LAMTSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define BTOLSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define ACRDSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define EMPBSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define HLPBSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDCIG    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDALC    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDMRJ    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDCOC    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDHER    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDHAL    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDINH    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDANL    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDTRN    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDSTM    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define UCDSED    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR = 1, 3)" ;
label define SKPSPTRD  1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt it alo"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SPTREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXRCVD  1 "Yes" 2 "No"
                       5 "Yes (NDTXNEED=YES) LOGICALLY ASSIGNED"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NDTXNEED  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NDTXRCVD=1)"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXRCVD=1)" ;
label define NDTXALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXMJ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXCOC   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXHER   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXHAL   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXINH   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXANL   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTRAN  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSTIM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSED   2 "No" 89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSOD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXDRG1  322 "Methamphetamine (speed or ice or cr"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       818 "Nicotine" 9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDRG2  9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDRG3  9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDRG4  9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDRG5  9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXSTEP  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTRSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTFAR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXBDHR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXOPEN  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTYPE  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXMONY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXHCAP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTCMP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXLANG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSPSV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSOR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXRSC1  3 "Programs hours were not convenient"
                       5 "Programs did not offer what I wanted"
                       9 "Counselors didnt meet ethnic/language n"
                       12 "Did not need it"
                       13 "Do not have a problem/feeling OK now"
                       14 "Do not want to (quit/get treatment)"
                       15 "Was using at the time/not ready/unmotiva"
                       16 "Can do it myself"
                       18 "Do not use/infrequently use drugs and al"
                       21 "Unsuccessful in the past"
                       24 "Can do it with the support of my family/"
                       26 "Treatment unavailable"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define BOOKED    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NOBOOKYR  83 "NOT BEEN ARRSTD & BKD PAST 12 MONTHS Lo"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (BOOK"
                       93 "NOT ARRESTED AND BOOKED PAST 12 MONTHS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (BOOKED=2)" ;
label define BKLARCNY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKBURGL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKAGASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKSMASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKMVTHFT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKROB     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKRAPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKMURDER  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKARSON   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKDRVINF  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKDRUNK   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKDRUG    1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKPROS    1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKVANDAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKOTH     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKOTHOFF  1 "Larceny or theft"
                       4 "Other assault, such as simple assault or"
                       10 "Driving under the influence"
                       11 "Drunkenness or other liquor law violatio"
                       12 "Possession or sale of drugs"
                       14 "Oth proprty offns:- fraud, poss stln goo"
                       15 "Other offenses (NOT SPECIFIED)"
                       16 "Weapons offenses"
                       17 "Other offenses against persons"
                       18 "Violation of court order, parole, probat"
                       19 "Public order offenses"
                       20 "Juvenile status offenses" 22 "Traffic violations"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROBATON  1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PAROLE    1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRVALDR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRIVEAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRIVEDR   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPTMTRD  1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define TMTREAD   1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXEVER    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TXTIMELF  0 "No times"
                       975 "Indicated treatment received at least on"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned (TXEV"
                       994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYRFREQ  0 "No times"
                       975 "Indicated treatment received at least on"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned (TXEV"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTHOSP"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALRFIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTRFIN"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALRFOP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTRFOP"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALMHC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTMHC"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALEMRG  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED from TXLTEMRG"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALDOC   1 "Yes" 2 "No" 5 "Yes LOGICALLY ASSIGNED from TXLTDOC"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALJAIL  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED from TXLTJAIL"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALSHG   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTSHG"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALSOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTSOP"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALSP    4 "AA or NA or CA" 5 "Residential placement"
                       10 "Church or religious influence"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       19 "Alternative medicine" 22 "Hospital"
                       24 "Drug treatment or rehab. center"
                       25 "Mental health center"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTHOSP"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRFIN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTRFIN"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRFOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTRFOP"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRMHC   1 "Yes" 2 "No" 5 "Yes LOGICALLY ASSIGNED from TXLTMHC"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDREMRG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTEMRG or"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRDOC   1 "Yes" 2 "No" 5 "Yes LOGICALLY ASSIGNED from TXLTDOC"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRJAIL  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED from TXLTJAIL"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRSHG   1 "Yes" 2 "No" 5 "Yes LOGICALLY ASSIGNED from TXLTSHG"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRSOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED from TXLTSOP"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRSP    4 "AA or NA or CA" 5 "Residential placement"
                       10 "Church or religious influence"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       16 "Home, family" 19 "Alternative medicine"
                       22 "Hospital" 24 "Drug treatment or rehab. center"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYREMRG  0 "No times"
                       975 "Indicated treatment received at least on"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned (TXEV"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXADGREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the pas"
                       3 "More than 12 months ago but within the p"
                       4 "More than 3 years ago"
                       8 "Treatment in past year LOGICALLY ASSIGNE"
                       9 "Treatment in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically as"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHOSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTRFIN  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTRFOP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTMHC   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTEMRG  1 "Response marked"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTDOC   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTJAIL  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSHG   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSOP   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSP    4 "AA or NA or CA" 5 "Residential placement"
                       10 "Church or religious influence"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       16 "Home, family" 18 "Homeless shelter"
                       19 "Alternative medicine" 22 "Hospital"
                       24 "Drug treatment or rehab. center"
                       25 "Mental health center"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTMJ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTINH   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTANL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTRAN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSTIM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSED   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSOD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Treatment drug unknown, LOGICALLY ASSIGN"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTA     161 "Rohypnol, Roofies, Rope, Rophynol, Rople"
                       241 "Prozac" 322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       805 "Cocaine, coca, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       814 "Caffeine" 9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXLTB     318 "Ritalin, Methylphenidate"
                       339 "Amphetamines (speed generically)" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTC     9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXLTD     9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXLTE     9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXDRGA    116 "Methaqualone, Parest, Quaalude, Sopor"
                       201 "Valium" 207 "Ativan" 209 "Xanax" 241 "Prozac"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 407 "Demerol"
                       420 "OTHER Analgesic, NOT SPECIFIED" 447 "Synalgos DC"
                       601 "LSD (acid, white lightning) [see als"
                       702 "Heroin" 705 "Speed Ball (heroin + cocaine)"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coca, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       814 "Caffeine" 9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXDRGB    322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       434 "Anexia, Co-Gesic, Hydrocodone, Lortab, T"
                       601 "LSD (acid, white lightning) [see als"
                       702 "Heroin" 803 "sic" 805 "Cocaine, coca, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXDRGC    702 "Heroin" 805 "Cocaine, coca, coke" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXDRGD    9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXDRGE    9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXOUTC    1 "Still in treatment"
                       2 "Successfully completed treatment"
                       3 "Had a problem with program"
                       4 "Couldnt afford to continue treatment"
                       5 "Family needed me" 6 "Began using drug(s) again"
                       7 "Other outcome, not specified"
                       8 "Didnt need treatment"
                       10 "Successful because of own efforts, not t"
                       11 "Use to a lesser extent" 12 "Kicked out of program"
                       13 "Moved"
                       15 "Discontinued treatment, success unknown"
                       16 "Completed treatment, outcome unknown"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXTIME    0 "No days"
                       9975 "Indicated treatment received at least on"
                       9989 "LEGITIMATE SKIP Logically assigned (TXEV"
                       9995 "BAD DATA" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDINS   1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCARE  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCAID  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSAVE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDFMLY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDEMPL  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDFREE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSOS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes, payment source not specified LOGICA"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSP    1 "Health Insurance" 2 "Own savings or earnings"
                       3 "Family member" 6 "Free" 8 "Friend/Sponsor"
                       9 "State/city public assistance/welfare/rel"
                       10 "Court" 12 "School"
                       14 "Veterans administration/military service"
                       15 "Treatment program" 17 "Social Security"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXENROLL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEV"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define SKYCPBAN  1 "Resp is 18-59 years old - SKIP TO PERS B"
                       2 "Resp is 60 years or older - SKIP TO DRIV"
                       3 "Respondent is 12-17 years old"
                       4 "18-59 years old - SKIP TO PB - LOG ASSIG"
                       5 "60 years or older - SKIP TO DB - LOG ASS"
                       6 "12-17 years old - LOGICALLY ASSIGNED" ;
label define SKPYCRD   1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YCREAD    1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       89 "LEGITIMATE SKIP Logically assigned"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YACTYNG   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YALLERGY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YARGUE    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YASTHMA   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YACOPPSX  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YLKANIML  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YBRAG     1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRBCONC  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YCNTHGTS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRBSIT   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDPTADLT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLONELY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLCONFU  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YCRYLOT   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YHONEST   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YMEANOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDAYDREM  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRYKLSF  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRYATTN  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDSTYTHG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDSTYOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDSBYPAR  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDSBYSCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDNTEATW  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDNTKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDNTGLTY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YJEALOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YHELPOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YAFRPLAC  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YAFRSCHL  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YAFRBAD   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLPRFCT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLNOLOV  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLGETME  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLWTHLS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YACCHURT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFIGHTS   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YGTEASED  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YKIDSTRB  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YHRVOICS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YACTTNK   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YALONE    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YLIE      1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YBITNAIL  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YNERVOUS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YBTWITCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YNGHTMAR  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YNOTKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDOBETTR  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YANXIOUS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLDIZZY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLGUILT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YEATMUCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFLTIRED  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YOVRWGHT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YACHES    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YHEADACH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YNAUSEA   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YEYEPROB  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YRASHES   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YCRAMPS   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YVOMIT    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YATTACK   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YPKBPART  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YPFRNDLY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRYTHNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSCPOOR   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YCLUMSY   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YOLDKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YYNGKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YRFSTALK  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YREPACTN  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YRUNHOME  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSCREAM   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSECRET   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSEETHNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSLFCONS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSETFIRE  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YWELHNDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSHOWOFF  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSHY      1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSLPLESS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSLPMORE  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YGDIMAG   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSPCHPRB  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSTDRGHT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSTEALHO  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSTEALPL  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDNTNEED  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDOSTRNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTHSTRNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSTUBORN  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YMOODS    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YENJOY    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSUSPICS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YDRTLANG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTHKKLSF  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YLKLAUGH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTALKMCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTEASE    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTEMPER   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTHNKSEX  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTHRTPEO  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YLKHELP   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YCONNEAT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRBSLEP  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YSKIPSCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YNOENRGY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YUNHAPPY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YLOUDER   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YUSEDRUG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YFAIROTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YENJYJOK  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YLIFEASY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YTRYHELP  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YWSOPPSX  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YINVOTH   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define YWORRY    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPY"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (SKPYCANS=1,3)" ;
label define SKPBDBAN  1 "Respondent is 12-15 years old - SKIP TO"
                       2 "Respondent is 16-17 years old - SKIP TO"
                       3 "Respondent is 12-15 years old LOGICALLY"
                       4 "Respondent is 16-17 years old LOGICALLY"
                       89 "LEGITIMATE SKIP Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define SKPPBRD   1 "Yes, I think that respondent can complet"
                       2 "No, I doubt that resp. can complt. it al"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PBREAD    1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XSEXYR    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XRELNOW   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XRELYR    1 "Yes" 2 "No"
                       3 "Yes LOG ASSN (1<= PB-4 <=5 or 1<= PB-5 <"
                       4 "No LOG ASSN (XNRELYR=1 or 3, and sex w/1"
                       5 "Yes LOGICALLY ASSIGNED (PB-19=1)"
                       6 "No LOGICALLY ASSIGNED (sex w/1 pers & P"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XRELCDV   1 "A condom was used every single time"
                       2 "A condom was used almost every single ti"
                       3 "A condom was used at least half of the t"
                       4 "A condom was used at least once but less"
                       5 "A condom was never used"
                       11 "Used condoms at least once LOGICALLY ASS"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT HAVE VAG SEX IN ON-GOING REL IN"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XRELCDA   1 "A condom was used every single time"
                       2 "A condom was used almost every single ti"
                       3 "A condom was used at least half of the t"
                       4 "A condom was used at least once but less"
                       5 "A condom was never used"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT HAVE ANAL SEX IN ON-GOING REL IN"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XNRELYR   1 "Yes" 2 "No"
                       3 "Yes LOG ASSN (1<= PB-7 <=5 or 1<= PB-8 <"
                       4 "No LOG ASSN (on-going rel and sex w/1 pe"
                       5 "Yes LOGICALLY ASSIGNED (PB-19=2)"
                       6 "No LOGICALLY ASSIGNED (sex w/1 pers & P"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XNRELCDV  1 "A condom was used every single time"
                       2 "A condom was used almost every single ti"
                       3 "A condom was used at least half of the t"
                       4 "A condom was used at least once but less"
                       5 "A condom was never used"
                       11 "Used condoms at least once LOGICALLY ASS"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT HAVE VAG SEX OUTSIDE ON-GO REL P"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XNRELCDA  1 "A condom was used every single time"
                       2 "A condom was used almost every single ti"
                       3 "A condom was used at least half of the t"
                       4 "A condom was used at least once but less"
                       5 "A condom was never used"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT HAVE ANAL SEX OUTSIDE ON-GO REL"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XYRDIFPP  1 "1 person" 2 "2 different people"
                       3 "3 to 5 different people"
                       4 "6 to 10 different people"
                       5 "11 to 20 different people"
                       6 "21 to 30 different people"
                       7 "31 or more different people"
                       11 "1 person (& sex in both types of relati"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XYRWTHMF  1 "Only males" 2 "Only females"
                       3 "Both males and females"
                       11 "Only males (R is male but vag sex also i"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XYRHIV    1 "Yes" 2 "No" 3 "I dont know"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XYRMONEY  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XYRDRUGS  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDLAST   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDPREG   1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (XCDRSN1=1 or 4)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDSTD    1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (XCDRSN1=2 or 4)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDNMESS  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XCDRSN1=4)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDOTRSN  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (1<=XCDRSN1<80)"
                       5 "Yes LOG ASSN (Yes not given in PB-16)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDRSN1   1 "Used condom to prevent pregnancy"
                       2 "Used condom to prevent sexually transmit"
                       4 "All of the above" 5 "Used condom out of curiosity"
                       6 "Used condom for hygienic/medical reasons"
                       7 "Used condom because wanted to, reg. rout"
                       8 "Used condom for general health and safet"
                       10 "Used condom bc not mutually monogamous r"
                       11 "Used condom to increase intensity/prolon"
                       12 "Used condom because partner requested"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XNCDPREG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=1)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDMONO  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=2)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDSTD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=3)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDOBC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=4)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDRELG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDPTNR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=6)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDNA    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=7)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDHOW   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDSAFE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (XNCDRSN1=9)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDORSN  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (1<=XNCDRSN1<80)"
                       5 "Yes LOG ASSN (Yes not given in PB-17)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XNCDRSN1  1 "We are trying to have a baby (get pregna"
                       2 "Did not need since only having sex with"
                       3 "Did not need since neither of us has AID"
                       4 "We used another birth control method"
                       6 "My partner did not want us to use a cond"
                       7 "A condom was not available or handy"
                       9 "The kind of sex we had was not that risk"
                       10 "Rape, nonconsensual sex" 11 "Already pregnant"
                       12 "Lesbian sex" 13 "Did not need to, no reason to"
                       14 "Oral sex" 15 "Have never discussed"
                       16 "Less pleasurable/intimate"
                       17 "Do not like them/do not want to/not inte"
                       18 "Allergic to latex" 19 "Too expensive"
                       20 "Never use them"
                       21 "Under the influence of drugs/alcohol"
                       22 "Infertile/sterile"
                       23 "Sterilized (tubal ligation, vasectomy, h"
                       24 "Inconvenient/interferes with the act"
                       25 "Personal reasons" 26 "Careless/forgot"
                       27 "Do not believe in/use/need birth control"
                       28 "Bad quality/defective condom"
                       29 "Condoms irritate/uncomfortable"
                       30 "Infrequent sex" 31 "Indicates distrust"
                       32 "Afraid of condoms/dont trust condoms"
                       33 "Will lose erection" 34 "Menstruating"
                       35 "Just for the fun of it"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDMOOD   1 "Agree" 2 "Disagree"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDRESP   1 "Agree" 2 "Disagree"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDFEEL   1 "Agree" 2 "Disagree"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDTRST   1 "Agree" 2 "Disagree"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDEMBR   1 "Agree" 2 "Disagree"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XCDCOST   1 "Agree" 2 "Disagree"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XRELLAST  1 "The last time, I had sex w/someone in on"
                       2 "The last time, I did not have sex in on-"
                       3 "Sex in on-going rel LOG ASSN (PB-19 NE 2"
                       4 "Sex not in on-going rel LOG ASSN (PB-19"
                       5 "Sex in on-going rel LOG ASSN (PB-19=2)"
                       6 "Sex not in on-going rel LOG ASSN (PB-19="
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XLFBLOOD  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XBLD385   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XLTBLDMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define XLTBLDYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 996 "MULTIPLE RESPONSE"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define XHIVTEST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XLTHIVMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define XLTHIVYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 996 "MULTIPLE RESPONSE"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define XHIVRSLT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SKPDBRD   1 "Yes, respondent can complete answer shee"
                       2 "No, I doubt that resp. can complt. it al"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DBREAD    1 "Wants interviewer to read questions alou"
                       2 "Wants to complete the answer sheet on hi"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VDRVYR    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VYRFREQ   1 "More than 300 days (every day or almost"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than 1 day a month)"
                       8 "3 to 5 days" 9 "1 to 2 days"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VALDRVYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED from DB-4 or DB-5"
                       5 "Yes LOGICALLY ASSIGNED from elsewhere on"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VALYRFRQ  1 "More than 300 days (which is every day o"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days" 9 "1 to 2 days"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VAL30USE  83 "DID NOT DRV W/IN 2 HRS DRNKNG PST 30 DAY"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT DRV W/IN 2 HRS DRNKNG PST 30 DAY"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VALCNODR  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VALCTIME  1 "More than 8 hours"
                       2 "At least 6 hours but not more than 8 hou"
                       3 "At least 4 hours but not more than 6 hou"
                       4 "At least 2 hours but not more than 4 hou"
                       5 "At least 1 hour but not more than 2 hour"
                       6 "At least 30 minutes but not more than 1"
                       7 "Less than 30 minutes"
                       8 "I only had one drink on this most recent"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VALDTIME  1 "2 hours"
                       2 "At least 1 hour but not more than 2 hour"
                       3 "At least 30 minutes but not more than 1"
                       4 "At least 15 minutes but not more than 30"
                       5 "At least 5 minutes but not more than 15"
                       6 "Less than 5 minutes"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJUSEYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (VMJDRVYR = 1,3)"
                       5 "Yes LOGICALLY ASSIGNED (VMJDRVYR = 5)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJDRVYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED from DB-11 or DB-"
                       5 "Yes LOGICALLY ASSIGNED from elsewhere on"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJALCYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJCOCYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJHERYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJHALYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJINHYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJANLYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJTRNYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJSTMYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJSEDYR  1 "Never" 2 "Rarely" 3 "Sometimes"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJOTHYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJYRS1   322 "Methamphetamine (speed or ice or cr"
                       420 "OTHER Analgesic, NOT SPECIFIED" 803 "sic"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VMJYRS2   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VMJYRS3   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VMJYRS4   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VMJYRS5   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VMJ30USE  83 "DID NOT DRV W/IN 2 HRS USE MJ PST 30 DAY"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT DRV W/IN 2 HRS USE MJ PST 30 DAY"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VLTMJALC  1 "I used only marijuana or hashish"
                       2 "I used marijuana or hashish with alcohol"
                       3 "I used marijuana or hashish with other d"
                       13 "Used mj or hash with oth drugs LOGICALLY"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJAL1  601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms), shooms"
                       805 "Cocaine, coca, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTMJAL2  601 "LSD (acid, white lightning) [see als"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTMJAL3  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTMJAL4  607 "OTHER Hallucinogen, NOT SPECIFIED"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTMJAL5  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTMJFRM  1 "My home" 2 "A friend or relatives home"
                       3 "A bar or nightclub" 4 "A restaurant"
                       5 "A sporting event" 6 "A concert" 7 "My workplace"
                       8 "Somewhere else"
                       18 "Somewhere else LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJFRS  9 "No place in particular (just driving aro"
                       10 "Drove while using marijuana/hashish" 18 "School"
                       19 "A park/recreational area" 20 "A party"
                       22 "Local hangout/place to use drugs/parking"
                       23 "Gambling establishment/race track/casino"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJTO   1 "My home" 2 "A friend or relatives home"
                       3 "A bar or nightclub" 4 "A restaurant"
                       5 "A sporting event" 6 "A concert" 7 "My workplace"
                       8 "No place in particular (I was just drivi"
                       9 "Somewhere else"
                       19 "Somewhere else LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJTOS  10 "Place to purchase drugs/alcohol"
                       13 "A bar or nightclub"
                       18 "No place in particular (just driving aro"
                       19 "A park/recreational area/gym" 20 "A restroom"
                       21 "Store/place of business"
                       22 "Local hangout/place to use drugs"
                       23 "Driving to another location, place unspe"
                       24 "Jail" 25 "A movie theater" 26 "School"
                       27 "Others workplace"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJHWY  1 "I drove on an interstate, highway, or fr"
                       2 "I drove only on smaller roads"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJURB  1 "Rural area (open country)"
                       2 "Urban area (city or town)"
                       3 "Suburban area (town just outside of a la"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJWKD  1 "Monday" 2 "Tuesday" 3 "Wednesday" 4 "Thursday"
                       5 "Friday" 6 "Saturday" 7 "Sunday"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJTIM  1 "12:00 AM to 2:59 AM" 2 "3:00 AM to 5:59 AM"
                       3 "6:00 AM to 8:59 AM" 4 "9:00 AM to 11:59 AM"
                       5 "12:00 PM to 2:59 PM" 6 "3:00 PM to 5:59 PM"
                       7 "6:00 PM to 8:59 PM" 8 "9:00 PM to 11:59 PM"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTMJABL  1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJNOWAY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJNHIGH  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJNPOLC  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJNODVR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJAPPT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJOTHER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJOTHSP  1 "There was no other way to get to where I"
                       2 "I wasnt high enough to cause a crash"
                       4 "No one else was available to drive my mo"
                       5 "I had an appointment or curfew"
                       6 "Was not thinking" 7 "No other place to use it"
                       8 "To get more drugs/alcohol"
                       9 "Just to have fun/drive around/just wante"
                       10 "To get something to eat"
                       11 "To run an errand/get something"
                       12 "Do not let anyone else drive my car/pref"
                       13 "To go to work/school"
                       14 "I was not as high as others with me" 15 "Bored"
                       16 "To relax/relieve stress" 17 "More convenient"
                       18 "Accustomed to driving high/unaffected/dr"
                       19 "Meet friends/family" 20 "To go home"
                       21 "To be by myself"
                       22 "Long drive ahead / on a road trip"
                       23 "My turn to drive" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJSTOP   1 "A lot more likely" 2 "A little more likely"
                       3 "No more likely" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VMJABIL   1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCUSEYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (VCCDRVYR = 1,3)"
                       5 "Yes LOGICALLY ASSIGNED (VCCDRVYR = 5)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCDRVYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED from DB-26 or DB-"
                       5 "Yes LOGICALLY ASSIGNED from elsewhere on"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCALCYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCMRJYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCHERYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCHALYR  1 "Never" 2 "Rarely" 3 "Sometimes"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCINHYR  1 "Never" 2 "Rarely" 3 "Sometimes"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCANLYR  1 "Never" 2 "Rarely" 3 "Sometimes"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCTRNYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCSTMYR  1 "Never" 2 "Rarely" 3 "Sometimes" 4 "Often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCSEDYR  1 "Never" 2 "Rarely" 3 "Sometimes"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCOTHYR  1 "Never" 2 "Rarely" 3 "Sometimes"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCYRS1   161 "Rohypnol, Roofies, Rope, Roples, Rufinal"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VCCYRS2   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VCCYRS3   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VCCYRS4   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VCCYRS5   9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VCC30USE  83 "DID NOT DRV W/IN 2 HRS USE COC PST 30 DA"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT DRV W/IN 2 HRS USE COC PST 30 DA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VLTCCALC  1 "I used only cocaine"
                       2 "I used cocaine with alcohol"
                       3 "I used cocaine with one or more other dr"
                       13 "Used cocaine with other drugs LOGICALLY"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCAL1  221 "OTHER Tranquilizer, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTCCAL2  803 "sic" 9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTCCAL3  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTCCAL4  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTCCAL5  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTCCFRM  1 "My home" 2 "A friend or relatives home"
                       3 "A bar or nightclub" 4 "A restaurant"
                       7 "My workplace" 8 "Somewhere else"
                       18 "Somewhere else LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCFRS  9 "No place in particular (just driving aro"
                       18 "School" 21 "Store / place of business"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCTO   1 "My home" 2 "A friend or relatives home"
                       3 "A bar or nightclub"
                       8 "No place in particular (I was just drivi"
                       9 "Somewhere else"
                       19 "Somewhere else LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCTOS  10 "Place to purchase drugs/alcohol"
                       18 "No place in particular (just driving aro"
                       21 "Store / place of business" 26 "School"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCHWY  1 "I drove on an interstate, highway, or fr"
                       2 "I drove only on smaller roads"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCURB  1 "Rural area (open country)"
                       2 "Urban area (city or town)"
                       3 "Suburban area (town just outside of a la"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCWKD  1 "Monday" 2 "Tuesday" 3 "Wednesday" 4 "Thursday"
                       5 "Friday" 6 "Saturday" 7 "Sunday"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCTIM  1 "12:00 AM to 2:59 AM" 2 "3:00 AM to 5:59 AM"
                       3 "6:00 AM to 8:59 AM" 4 "9:00 AM to 11:59 AM"
                       5 "12:00 PM to 2:59 PM" 6 "3:00 PM to 5:59 PM"
                       7 "6:00 PM to 8:59 PM" 8 "9:00 PM to 11:59 PM"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTCCABL  1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCNOWAY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCNHIGH  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCNPOLC  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCNODVR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCAPPT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCOTHER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCOTHSP  2 "I wasnt high enough to cause a crash"
                       5 "I had an appointment or curfew"
                       8 "To get more drugs/alcohol"
                       9 "Just to have fun/drive around/just wante"
                       11 "To run an errand/get something"
                       13 "To go to work/school" 16 "To relax/relieve stress"
                       18 "Accustomed to driving high/unaffected/dr"
                       20 "To go home" 22 "Long drive ahead / on a road trip"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCSTOP   1 "A lot more likely" 2 "A little more likely"
                       3 "No more likely" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VCCABIL   1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VTRUSEYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (VTRDRVYR = 1,3)"
                       5 "Yes LOGICALLY ASSIGNED (VTRDRVYR = 5)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VTRDRVYR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED from DB-41"
                       5 "Yes LOGICALLY ASSIGNED from elsewhere on"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VTR30USE  83 "DID NOT DRV W/IN 2 HRS USE TRQ PST 30 DA"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT DRV W/IN 2 HRS USE TRQ PST 30 DA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VLTTRMED  1 "I used tranquilizers for medical reason"
                       2 "I used tranquilizers for the experience"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTTRALC  1 "I used only tranquilizers"
                       2 "I used tranquilizers with alcohol"
                       3 "I used tranquilizers with one or more dr"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTTRAL1  241 "Prozac" 803 "sic" 805 "Cocaine, coca, coke"
                       891 "Famotidine, Pepcid" 893 "Estrogen"
                       894 "Depakene, Depakote, Valproic acid"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTTRAL2  225 "Desyrel, Trazodone hydrochloride, Trazor"
                       493 "IBU" 892 "Carafate. Sucralfate"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTTRAL3  427 "Darvocet" 874 "Premarin"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTTRAL4  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTTRAL5  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTTRABL  1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VSTUSEYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (VSTDRVYR = 1,3)"
                       5 "Yes LOGICALLY ASSIGNED (VSTDRVYR = 5)"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VSTDRVYR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED from DB-47"
                       5 "Yes LOGICALLY ASSIGNED from elsewhere on"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VST30USE  83 "DID NOT DRV W/IN 2 HRS USE STM PST 30 DA"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT DRV W/IN 2 HRS USE STM PST 30 DA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VLTSTMED  1 "I used stimulants for a medical reason"
                       2 "I used stimulants for the experience or"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTSTALC  1 "I used only stimulants"
                       2 "I used stimulants with alcohol"
                       3 "I used stimulants with one or more other"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTSTAL1  803 "sic" 897 "Synthroid, Levothyroxine"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSTAL2  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSTAL3  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSTAL4  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSTAL5  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSTABL  1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VSEUSEYR  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (VSEDRVYR = 1,3)"
                       5 "Yes LOGICALLY ASSIGNED (VSEDRVYR = 5)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VSEDRVYR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED from DB-53"
                       5 "Yes LOGICALLY ASSIGNED from elsewhere on"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VSE30USE  83 "DID NOT DRV W/IN 2 HRS USE SED PST 30 DA"
                       89 "LEGITIMATE SKIP Logically assigned"
                       93 "DID NOT DRV W/IN 2 HRS USE SED PST 30 DA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VLTSEMED  1 "I used sedatives for a medical reason"
                       2 "I used sedatives for the experience or f"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTSEALC  1 "I used only sedatives"
                       2 "I used sedatives with alcohol"
                       3 "I used sedatives with one or more other"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VLTSEAL1  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       805 "Cocaine, coca, coke"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSEAL2  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSEAL3  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSEAL4  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSEAL5  9989 "LEGITIMATE SKIP Logically assigned"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define VLTSEABL  1 "A lot" 2 "A little" 3 "Not at all"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SKPWKST3  1 "Work stat=Now in labor force (codes 1-4/"
                       2 "Work stat=Not in labor frc (5-11/25-32)"
                       3 "Work stat=Now in labor force LOGICALLY A"
                       4 "Work stat=Not in labor frc LOG ASSN - SK"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WORKDAYS  0 "No days" 89 "LEGITIMATE SKIP Logically assigned"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  0 "No days" 89 "LEGITIMATE SKIP Logically assigned"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPPREG   1 "Respondent is female less than 45 years"
                       2 "Respondent is female 45 years or older -"
                       3 "Respondent is male - SKIP"
                       4 "Female less than 45 LOGICALLY ASSIGNED"
                       5 "Female 45 years or older LOGICALLY ASSIG"
                       6 "Male LOGICALLY ASSIGNED - SKIP" ;
label define PREGNANT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PREGMOS   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPMHC    1 "Respondent is 18 years or older"
                       2 "Respondent is 12-17 years old - SKIP"
                       3 "18 or older LOGICALLY ASSIGNED"
                       4 "12 to 17 LOGICALLY ASSIGNED - SKIP" ;
label define DEPRESS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPDAYS   1 "All day long" 2 "Most of the day"
                       3 "About half the day" 4 "Less than half the day"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPFREQ   1 "Every day" 2 "Almost every day" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LOSTINT1  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TIRED1    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WTCHNG1   1 "Gained weight" 2 "Lost weight"
                       3 "Both gained and lost weight" 4 "Stayed the same"
                       5 "Respondent was on a diet"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LBSCHNG1  989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SLPLOSS1  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLPFREQ1  1 "Every night" 2 "Nearly every night" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CONCEN1   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DOWN1     1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IDEAT1    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPDEP1   1 "Yes" 2 "No - SKIP" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPWKS1   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPMO1    85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPYR1    985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define LOSTINT2  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define LOSINDAY  1 "All day long" 2 "Most of the day"
                       3 "About half the day" 4 "Less than half the day"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define LOSINFRQ  1 "Every day" 2 "Almost every day" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TIRED2    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WTCHNG2   1 "Gained weight" 2 "Lost weight"
                       3 "Both gained and lost weight" 4 "Stayed the same"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LBSCHNG2  989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SLPLOSS2  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SLPFREQ2  1 "Every night" 2 "Nearly every night" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CONCEN2   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DOWN2     1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IDEAT2    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPDEP2   1 "Yes" 2 "No - SKIP" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPWKS2   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPMO2    89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPYR2    985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WORRIED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WOREND    1 "Ended" 2 "Still going on"
                       3 "Ended LOGICALLY ASSIGNED"
                       4 "Still going on LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORNOMO1  9989 "LEGITIMATE SKIP Logically assigned"
                       9994 "DONT KNOW" 9995 "BAD DATA" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define WORHAPN1  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORSERI1  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORDIFF1  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORNOMO2  9989 "LEGITIMATE SKIP Logically assigned"
                       9994 "DONT KNOW" 9995 "BAD DATA" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define WORHAPN2  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORSERI2  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORDIFF2  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPWOR    1 "Question HE-33 or HE-37 = 6 months or mo"
                       2 "Question HE-33 or HE-37 < 6 mo. - SKIP"
                       3 "Q.HE-33 or HE-37 = 6 mo. or more LOG ASS"
                       4 "Q.HE-33 or HE-37 < 6 mo. LOG ASSN - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORREST   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WOREDGE   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORIRRIT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORHEART  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORTIRED  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORSLEEP  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORFAINT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARPUB   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEAROUT   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARBRDG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPFEAR1  1 "Any yes answer" 2 "All answered no - SKIP"
                       3 "Any yes answer LOGICALLY ASSIGNED"
                       4 "All answered no LOGICALLY ASSIGNED - SKI"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEAROFT   1 "Every time" 2 "Most of the time"
                       3 "Some of the time" 4 "Only one or two times"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEARYRS   1 "Less than 1 year" 2 "Between 1 and 5 years"
                       3 "More than 5 years"
                       5 "Between 1 and 5 yrs LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEARMOS   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARFANT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARTRAP  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARHELP  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIC1    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PANIC2    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PANICNUM  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PANICMO   89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANICYR   985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PANIDANG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPFEAR2  1 "Any yes answer" 2 "All answered no - SKIP"
                       3 "Any yes answer LOGICALLY ASSIGNED"
                       4 "All answered no LOGICALLY ASSIGNED - SKI"
                       89 "LEGITIMATE SKIP Logically assigned"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PANIFEAR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PANINOFR  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIHART  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIPAIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANISWET  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANISHAK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIHOT   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIUNRL  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NUERTMT   0 "No times" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NUHSPOV   0 "No nights" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NUHSPPE   0 "No nights" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OUTPTPE   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PROXABLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (FAMS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (FAMSKIP=1)" ;
label define PROXYREL  1 "Respondents spouse/live-in partner"
                       2 "Respondents father" 3 "Respondents mother"
                       4 "Respondents brother" 5 "Respondents sister"
                       6 "Other family member (specify relation to"
                       20 "Parent/Guardian"
                       21 "Step/Adopted/Foster Parent/Future Step P"
                       50 "Grandparent/Great+ Grandparent"
                       61 "Friend/Roommate/Companion"
                       71 "Cousin/Cousins Spouse"
                       91 "Other Non-Relative, Gender not specified"
                       110 "Husband"
                       121 "Step/Adopted/Foster Father/Future Step F"
                       130 "Son" 133 "Grandson"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunts Husband"
                       191 "Other Male Non-Relative" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother/Future Step M"
                       230 "Daughter" 242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother" 270 "Aunt"
                       271 "Female Cousin/Cousins Wife"
                       281 "Other Female God Relative"
                       292 "Other Female, Relation Unspecified"
                       989 "LEGITIMATE SKIP Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PROXHOME  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXJOIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CAREUSU   1 "Yes" 2 "No" 3 "Dont know"
                       4 "There is more than one place" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NCARERSN  1 "Two or more usual doctors/places"
                       2 "Dont need a doctor"
                       3 "Dont like/trust/believe in doctors"
                       4 "Dont know where to go"
                       5 "Previous doctor is not available/moved"
                       6 "No insurance/cant afford it"
                       7 "Speak a different language"
                       8 "No care available/care too far away/inco"
                       9 "Other specify (see NCRRSNSP & NCRRSNSC)"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NCRRSNSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NCRRSNSC  1 "Two or more usual doctors/places"
                       2 "Dont need a doctor"
                       3 "Dont like/trust/believe in doctors"
                       4 "Dont know where to go"
                       5 "Previous doctor is not available/moved"
                       6 "No insurance/cant afford it"
                       8 "No care available/care too far away or i"
                       10 "New to area/recently moved"
                       11 "Do not have a regular doctor"
                       12 "Self treatment/treatment by family membe"
                       13 "Religious reasons"
                       14 "Health care plan determines source"
                       15 "Hospital/urgent care/clinic" 16 "School/workplace"
                       17 "Medicare/Medicaid/public assistance"
                       18 "Alternative medicine"
                       19 "Difficulty getting to medical care bc of"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CAREOFT   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PYRCARE   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PYRCRTYP  1 "Doctors office or private clinic"
                       2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient c"
                       5 "Private/other hospital outpatient clinic"
                       6 "Hospital emergency room" 7 "HMO"
                       9 "VA hospital or clinic"
                       10 "Military health care facility"
                       11 "Some other place specified (see PYRCRTSP"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PYRCRTSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PYRCRTSC  2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient c"
                       5 "Private/other hospital outpatient clinic"
                       12 "Self treatment/family member" 15 "Religion/church"
                       16 "Alternative medicine" 18 "Family planning clinic"
                       19 "Indian clinic or hospital"
                       20 "Drug treatment/rehab center"
                       22 "Workmans Compensation health provider"
                       23 "Prison/correctional facility"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CARENOW   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNRSNNCR  1 "Respondent changed residence/moved"
                       2 "Respondent changed jobs"
                       3 "Employer changed insurance companies"
                       4 "Formal usual source left area"
                       5 "Owed money to former usual source"
                       6 "Dissatsfd with frmr source/like new sour"
                       7 "Medical care needs changed"
                       8 "Frmr usual source stopped taking ins/cov"
                       9 "Other reason specified (see MNRSNNSP/SC)"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MNRSNNSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNRSNNSC  1 "Respondent changed residence/moved"
                       2 "Respondent changed jobs"
                       3 "Employer change insurance companies"
                       4 "Former usual source left area"
                       5 "Owed money to former usual source"
                       6 "Dissatsfd with frmr source/liked new sou"
                       7 "Medical care needs changed"
                       11 "Medical care received through workmans"
                       12 "Do not need/like doctors"
                       13 "Cannot afford it/no insurance" 16 "Former student"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UCARETYP  1 "Doctors office or private clinic"
                       2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient c"
                       5 "Private/other hospital outpatient clinic"
                       6 "Hospital emergency room" 7 "HMO"
                       8 "Psychiatric hospital or clinic"
                       9 "VA hospital or clinic"
                       10 "Military health care facility"
                       11 "Some other place specified (see UCRTYPSP"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UCRTYPSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UCRTYPSC  1 "Doctors office or private clinic"
                       2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient c"
                       5 "Private/other hospital outpatient clinic"
                       6 "Hospital emergency room"
                       7 "HMO (Health maintenance organization/pre"
                       9 "VA hospital or clinic"
                       10 "Military health care facility"
                       12 "Self treatment/family member" 13 "Friend"
                       14 "Urgent care/walk-in medical facility"
                       15 "Religion/church" 16 "Alternative medicine"
                       17 "Non-physician health care professional"
                       18 "Family planning clinic"
                       19 "Indian clinic or hospital"
                       23 "Prison/correctional facility"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MEDICAID  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRVHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GRPHLTIN  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PDHINPRM  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLTINALC  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINDRG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINMNT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOC1      1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOC2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SSI1      1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SSI2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PUB1      1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PUB2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AFDC      1 "AFDC/ADC" 2 "OTHER" 3 "BOTH"
                       4 "AFDC/ADC Logically assigned"
                       5 "OTHER Logically assigned"
                       6 "BOTH Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INT1      1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INT2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CHD1      1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CHD2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OTH1      1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTH2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FSTAMP    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PINC1     1 "$20,000 or more" 2 "Less than $20,000"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPTFMIN  1 "Yes" 2 "No - SKIP" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FINC1     1 "$20,000 or more" 2 "Less than $20,000"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TELNO     0 "No telephone lines" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IRPINSUR  1 "Yes, respondent does have private health"
                       2 "No, respondent does not have private hea" ;
label define IIPINSUR  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insuran"
                       2 "No, respondent does not have health insu" ;
label define IIINSUR   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRSOC1    1 "Yes" 2 "No" ;
label define IISOC1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRSSI1    1 "Yes" 2 "No" ;
label define IISSI1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRPUB1    1 "Yes" 2 "No" ;
label define IIPUB1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAFDC    1 "AFDC/ADC" 2 "OTHER" 3 "BOTH"
                       89 "LEGITIMATE SKIP Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IIAFDC    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINT1    1 "Yes" 2 "No" ;
label define IIINT1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRCHD1    1 "Yes" 2 "No" ;
label define IICHD1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IROTH1    1 "Yes" 2 "No" ;
label define IIOTH1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRFSTAMP  1 "Yes" 2 "No" ;
label define IIFSTAMP  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRPINC1   1 "$20,000 or more" 2 "Less than $20,000" ;
label define IIPINC1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRFINC1   1 "$20,000 or more" 2 "Less than $20,000"
                       89 "LEGITIMATE SKIP Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IIFINC1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSOC2    1 "Yes" 2 "No" ;
label define IISOC2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSSI2    1 "Yes" 2 "No" ;
label define IISSI2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRPUB2    1 "Yes" 2 "No" ;
label define IIPUB2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINT2    1 "Yes" 2 "No" ;
label define IIINT2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRCHD2    1 "Yes" 2 "No" ;
label define IICHD2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IROTH2    1 "Yes" 2 "No" ;
label define IIOTH2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRKIDS    0 "No children under 12" ;
label define PARSTAT   1 "Respondent has no children"
                       2 "Respondent has at least one child < 2 yr"
                       3 "Resp has at least 1 child < 17, none < 2" ;
label define FEMBABY   0 "No" 1 "Yes" ;
label define FEMKIDS   0 "No" 1 "Yes" ;
label define MALEBABY  0 "No" 1 "Yes" ;
label define MALEKIDS  0 "No" 1 "Yes" ;
label define F15_44    0 "Otherwise" 1 "Female age 15-44" ;
label define M15_44    0 "Otherwise" 1 "Male age 15-44" ;
label define PREG      0 "Otherwise" 1 "Pregnant female age 12-44" ;
label define PREG2     1 "Pregnant (PREGNANT = 1,3)"
                       2 "Not pregnant (PREGNANT = 2)"
                       3 "Males/Females not age 12-44 (PREGNANT ="
                       99 "Unknown (PREGNANT = 94,97,98)" ;
label define TRIMEST   1 "1st 3 months of pregnancy (PREG=1 & PRE"
                       2 "2nd 3 months of pregnancy (PREG=1 & PRE"
                       3 "Last 3 months of pregnancy (PREG=1 & PR"
                       4 "Males/Not pregnant females (PREG=0)"
                       99 "Unknown (PREG=1 and PREGMOS=85,94,98)" ;
label define INDCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define PERINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000+" ;
label define PERINC2   1 "$0-9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define PERINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years Old" ;
label define TOTCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define FAMINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,000" 5 "$75,000+" ;
label define FAMINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define FAMINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years old" ;
label define WELFARE   1 "Yes, respondent or another fam member on"
                       2 "No, there was no one in the family on we" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 12 m"
                       3 "12 or more months ago but less than 3 ye"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE V" ;
label define NEDFLAG4  0 "Never used (GNNDLLIF=2,97,98)"
                       1 "Ever used (GNNDLLIF=1,3)" ;
label define NEDYR4    0 "Never used (NEEDLREC=3,4,9,91,98)"
                       1 "Ever used (NEEDLREC=1,2)" ;
label define WITHDRW   98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOMCOM    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ANXDEP    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOCPROB   98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define THPROB    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ATTPROB   98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DELBEH    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AGGBEH    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WITHDRWT  998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SOMCOMT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ANXDEPT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SOCPROBT  998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define THPROBT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ATTPROBT  998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define DELBEHT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AGGBEHT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SXHIVLF   1 "Yes" 2 "No" 12 "Never actively tested for HIV"
                       94 "DONT KNOW" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXHIVYR   1 "Yes" 2 "No"
                       11 "Tested in 1995, same month as INTDATE"
                       12 "Tested in 1995, month unknown"
                       22 "Tested in lifetime but not actively in p"
                       32 "Never actively tested in lifetime" 94 "DONT KNOW"
                       97 "REFUSED" 98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXREL     1 "Did not have sex in past year"
                       2 "Sex w/ 1 pers past yr, only on-going rel"
                       3 "Sex w/ 1 pers past yr, on-go & outside"
                       4 "Sex w/ 1 pers past yr, only outside on-g"
                       5 "Sex w/ >1 pers past yr, only on-going re"
                       6 "Sex w/ >1 pers past yr, on-go & outside"
                       7 "Sex w/ >1 pers pst yr, only outside on-g"
                       14 "Sex w/ 1 person pst yr, type of rel unkn"
                       16 "Sex w/ >1 pers pst yr, >=1 relationship"
                       25 "Sex only in on-going rels pst yr, # part"
                       26 "Sex in both types of rel pst yr, # partn"
                       27 "Sex only outside on-going rel, # partner"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXRELMAR  1 "Did not have sex in past year"
                       2 "Married, sex w/ 1 person, only on-going"
                       3 "Other mar stat, sex w/ 1 pers, only on-g"
                       4 "Oth mar stat, sx w/1 pers, on-go & outs"
                       5 "Oth mar stat, sx w/1 pers, outside on-go"
                       6 "Sex w/ >1 pers (any mar stat), only on-g"
                       7 "Sex w/ >1 pers, on-going & outside on-g"
                       8 "Sex w/ >1 pers, only outside on-going re"
                       10 "Married, sex w/ 1 pers, >=1 relationship"
                       11 "Married, sex w/ 1 pers, on-go & outside"
                       12 "Married, sex w/ 1 pers, only outside on-"
                       14 "Oth mar stat, sex w/ 1 pers, >=1 rel unk"
                       17 "Sex w/ > 1 pers, >=1 relationship unknow"
                       26 "Sex only in on-going rels, # partners un"
                       27 "Sex in both types of rel, # partners unk"
                       28 "Sex only outside on-going rel, # partner"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXCONDYR  1 "Did not have sex in past year"
                       2 "No vaginal or anal sex, past year"
                       3 "Condoms always used (where applicable)"
                       4 "Condoms used always or nearly always (wh"
                       5 "Condoms used at least half the time (whe"
                       6 "Condoms used less than half the time (wh"
                       7 "Condoms never used for some behavs (wher"
                       8 "Condoms never used for any behavs (where"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXRSKANY  1 "Yes" 2 "No" 12 "No except for XHIVYR=3"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXRSKCNT  0 "None of 5 higher-risk behaviors, past ye"
                       1 "1 of 5 higher-risk behaviors, past year"
                       2 "2 of 5 higher-risk behaviors, past year"
                       3 "3 of 5 higher-risk behaviors, past year"
                       10 "No higher-risk behavs except for XHIVYR="
                       11 "1 of 5 higher-risk behaviors and XHIVYR="
                       12 "2 of 5 higher-risk behaviors and XHIVYR="
                       13 "3 of 5 higher-risk behaviors and XHIVYR="
                       14 "4 of 5 higher-risk behaviors and XHIVYR="
                       51 "1 higher-risk behav, at least 1 behav un"
                       52 "2 higher-risk behavs, at least 1 behav u"
                       53 "3 higher-risk behavs, at least 1 behav u"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXDRANY   1 "Yes" 2 "No" 12 "No except for XHIVYR=3"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define SXDRCNT   0 "None of 7 higher-risk behaviors, past ye"
                       1 "1 of 7 higher-risk behaviors, past year"
                       2 "2 of 7 higher-risk behaviors, past year"
                       3 "3 of 7 higher-risk behaviors, past year"
                       4 "4 of 7 higher-risk behaviors, past year"
                       10 "No higher-risk behavs except for XHIVYR="
                       11 "1 of 7 higher-risk behaviors and XHIVYR="
                       12 "2 of 7 higher-risk behaviors and XHIVYR="
                       13 "3 of 7 higher-risk behaviors and XHIVYR="
                       14 "4 of 7 higher-risk behaviors and XHIVYR="
                       15 "5 of 7 higher-risk behaviors and XHIVYR="
                       51 "1 higher-risk behav, at least 1 behav un"
                       52 "2 higher-risk behavs, at least 1 behav u"
                       54 "4 higher-risk behavs, at least 1 behav u"
                       88 "SEX IN PAST YR UNKNOWN" 97 "REFUSED"
                       98 "UNKNOWN, ALL OTHER REASONS"
                       99 "LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)" ;
label define MDESFS1   99 "LEGITIMATE SKIP" ;
label define MDESFS3   99 "LEGITIMATE SKIP" ;
label define PROBMDE1  99.0000 "LEGITIMATE SKIP" ;
label define PROBMDE3  99.0000 "LEGITIMATE SKIP" ;
label define MDE1      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define MDE3      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define GADSFS1   99 "LEGITIMATE SKIP" ;
label define GADSFS3   99 "LEGITIMATE SKIP" ;
label define PROBGAD1  99.0000 "LEGITIMATE SKIP" ;
label define PROBGAD3  99.0000 "LEGITIMATE SKIP" ;
label define GAD1      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define GAD3      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define AGPSFS1   99 "LEGITIMATE SKIP" ;
label define AGPSFS3   99 "LEGITIMATE SKIP" ;
label define PROBAGP1  99 "LEGITIMATE SKIP" ;
label define PROBAGP3  99 "LEGITIMATE SKIP" ;
label define AGP1      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define AGP3      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define PASFS1    99 "LEGITIMATE SKIP" ;
label define PASFS3    99 "LEGITIMATE SKIP" ;
label define PROBPA1   99.0000 "LEGITIMATE SKIP" ;
label define PROBPA3   99.0000 "LEGITIMATE SKIP" ;
label define PA1       0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define PA3       0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define BHOUR     98 "BLANK (NO ANSWER)" ;
label define BMIN      98 "BLANK (NO ANSWER)" ;
label define BAP       98 "BLANK (NO ANSWER)" ;
label define EAP       98 "BLANK (NO ANSWER)" ;
label define LANGVER   1 "English" 2 "Spanish" ;
label define UNDINT    1 "No difficulty--no language or reading pr"
                       2 "Just a little difficulty--almost no lang"
                       3 "A fair amount of difficulty--some lang/r"
                       4 "A lot of difficulty--considerable lang/r"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able t"
                       3 "Minor distractions"
                       5 "Person(s) in the room or listening 1/3 o"
                       7 "Serious interruption of privacy more tha"
                       9 "Constant presence of other person(s)"
                       85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SPRES     2 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PARPRES   3 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OARPRES   4 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OAPRES    5 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CPRES     6 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OPRESNSP  7 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OPRESSPA  10 "Spouse"
                       21 "Step/Adopted/Foster Parent/Future Step P"
                       30 "Own Child/Own Half Child" 33 "Grandchild"
                       37 "Child, Relation Unspecified"
                       61 "Friend/Roommate/Companion"
                       71 "Cousin/Cousins Spouse"
                       84 "Neighbor/Co-Worker/Visitor"
                       90 "Other Relative, Gender not specified"
                       91 "Other Non-Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       113 "Childs Father"
                       121 "Step/Adopted/Foster Father/Future Step F"
                       122 "Father/Step Father/Future Father In-Law"
                       130 "Son" 133 "Grandson" 140 "Brother/Half Brother"
                       142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunts Husband" 172 "Nephew"
                       191 "Other Male Non-Relative"
                       192 "Other Male, Relation Unspecified" 210 "Wife"
                       220 "Mother/Female Guardian"
                       222 "Mother/Step Mother/Future Mother In-Law"
                       230 "Daughter" 233 "Granddaughter"
                       240 "Sister/Half Sister" 242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Compa"
                       270 "Aunt" 272 "Niece"
                       282 "Female Housekeeper/Maid/Caretaker/Butler"
                       292 "Other Female, Relation Unspecified"
                       320 "Parents/Guardians"
                       337 "Children, Relation Unspecified" 340 "Siblings"
                       361 "Friends/Roommates/Companions"
                       384 "Neighbors/Co-Workers/Visitors"
                       391 "Other Non-Relatives, Gender not specifie"
                       392 "Others, Relation and Gender Unspecified"
                       430 "Sons" 540 "Sisters/Half Sisters"
                       900 "NOT A PERSON" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define OPRESSPB  37 "Child, Relation Unspecified"
                       61 "Friend/Roommate/Companion"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       230 "Daughter" 242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother" 270 "Aunt"
                       337 "Children, Relation Unspecified"
                       361 "Friends/Roommates/Companions"
                       392 "Others, Relation and Gender Unspecified"
                       900 "NOT A PERSON" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WHOMARKD  1 "Respondent marked all the Answer Sheet r"
                       2 "Interviewer marked all the Answer Sheet"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define QUARTER   1 "Quarter 1" 2 "Quarter 2" 3 "Quarter 3"
                       4 "Quarter 4" ;
label define FAMSKIP   0 "Respondent has other family members in h"
                       1 "Respondent didnt have other family in h" ;
label define GQTYPE    1 "Halfway House" 2 "Boarding House" 3 "College Dorm"
                       4 "Shelter" 5 "Other" 9 "Not Group Quarters" ;
label define PDEN      1 "Segment in a MSA with 1 million or more"
                       2 "Segment in a MSA with fewer than 1 milli"
                       3 "Segment not in MSA" ;
label define PDEN2     1 "Segment in MSA with 1 million or more pe"
                       2 "Segm. in a MSA from 250000 to 999999 per"
                       3 "Segment in a MSA with fewer than 250000"
                       4 "Segment not in a MSA and not in a rural"
                       5 "Segment not in a MSA and in a rural area" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define RURORURB  1 "Rural" 2 "Urban" ;
label define RELINTHH  0 "No other person in hhold interviewed" 10 "Spouse"
                       20 "Parent/guardian" 21 "Step/adopted/foster parent"
                       22 "Parent in-law (also step-)" 25 "Parents sibling"
                       30 "Child" 31 "Step/adopted/foster child"
                       32 "Child in-law" 35 "Siblings child" 36 "Cousin"
                       37 "Grandchild" 40 "Sibling"
                       41 "Step/adopted/foster sibling" 42 "Sibling in-law"
                       50 "Grandparent" 60 "Live in partner, fiancee"
                       61 "Friend/roommate" 70 "Other, relative"
                       71 "Other, non-relative"
                       99 "Other, relation unspecified" ;
label define MJTOT3    1 "1-2 days" 2 "3-11 days" 3 "12-100 days"
                       4 "101+ days" 5 "NEVER USED" 99 "UNKNOWN/NO ANSWER" ;
label define COCTOT3   1 "1-2 days" 2 "3-11 days" 3 "12-100 days"
                       4 "101+ days" 5 "NEVER USED/NO ANSWER" 99 "UNKNOWN" ;
label define ALCDAYS2  1 "None or never used alcohol" 2 "1-2 days"
                       3 "3-4 days" 4 "5-19 days" 5 "20-30 days" 6 "UNKNOWN" ;
label define AGECAT4   1 "12-20" 2 "21 and older" ;
label define MJDY30A3  1 "1-2 days" 2 "3-4 days" 3 "5-19 days" 4 "20-30 days"
                       5 "NONE/NEVER USED MARIJUANA" 6 "UNKNOWN/NO ANSWER" ;
label define ALCDAYS3  1 "0" 2 "1-4" 3 "5-19" 4 "20-30" 6 "UNKNOWN" ;
label define DRINKER2  0 "No" 1 "Yes" ;
label define HVYDRK3   0 "No" 1 "Yes" ;
label define AVCIG2    1 "0" 2 "15 cigarettes or less"
                       3 "16 cigarettes or more" 4 "UNKNOWN" ;
label define RACESEX   1 "White male" 2 "Black male" 3 "Hispanic male"
                       4 "White female" 5 "Black female" 6 "Hispanic female"
                       99 "Other males and females" ;
label define NOTMARJ   0 "No" 1 "Yes" ;
label define BINGDRK2  0 "No" 1 "Yes" ;
label define RACESEX2  1 "White male" 2 "Black male" 3 "Hispanic male"
                       4 "Other male" 5 "White female" 6 "Black female"
                       7 "Hispanic female" 8 "Other female" ;
label define IRBTCIG2  0 "No" 1 "Yes" ;
label define IRBTALC2  0 "No" 1 "Yes" ;
label define IRBTMRJ2  0 "No" 1 "Yes" ;
label define IRBTCOC2  0 "No" 1 "Yes" ;
label define IRGRCIG2  0 "No" 1 "Yes" ;
label define IRGRALC2  0 "No" 1 "Yes" ;
label define IRGRMRJ2  0 "No" 1 "Yes" ;
label define IRGRCOC2  0 "No" 1 "Yes" ;
label define IRLACIG2  0 "No" 1 "Yes" ;
label define IRLAALC2  0 "No" 1 "Yes" ;
label define IRLAMRJ2  0 "No" 1 "Yes" ;
label define IRLACOC2  0 "No" 1 "Yes" ;
label define IRACCIG2  0 "No" 1 "Yes" ;
label define IRACALC2  0 "No" 1 "Yes" ;
label define IRACMRJ2  0 "No" 1 "Yes" ;
label define IRACCOC2  0 "No" 1 "Yes" ;
label define IREMCIG2  0 "No" 1 "Yes" ;
label define IREMALC2  0 "No" 1 "Yes" ;
label define IREMMRJ2  0 "No" 1 "Yes" ;
label define IREMCOC2  0 "No" 1 "Yes" ;
label define IRHLCIG2  0 "No" 1 "Yes" ;
label define IRHLALC2  0 "No" 1 "Yes" ;
label define IRHLMRJ2  0 "No" 1 "Yes" ;
label define IRHLCOC2  0 "No" 1 "Yes" ;
label define IRUCCIG2  0 "No" 1 "Yes" ;
label define IRUCALC2  0 "No" 1 "Yes" ;
label define IRUCMRJ2  0 "No" 1 "Yes" ;
label define IRUCCOC2  0 "No" 1 "Yes" ;
label define AVCIG3    0 "No" 1 "Yes" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define MRJ2PROB  0 "No" 1 "Yes" ;
label define MRJ3PROB  0 "No" 1 "Yes" ;
label define COC2PROB  0 "No" 1 "Yes" ;
label define COC3PROB  0 "No" 1 "Yes" ;
label define CIG2PROB  0 "No" 1 "Yes" ;
label define CIG3PROB  0 "No" 1 "Yes" ;
label define ALC2PROB  0 "No" 1 "Yes" ;
label define ALC3PROB  0 "No" 1 "Yes" ;
label define CIGTRY2   99 "LEGITIMATE SKIP/NO ANSWER" ;
label define ALCTRY2   99 "LEGITIMATE SKIP/NO ANSWER" ;
label define MJAGE2    99 "NEVER USED/NO ANSWER" ;
label define INHAGE2   99 "NEVER USED/NO ANSWER" ;
label define COCAGE2   99 "LEGITIMATE SKIP/NO ANSWER" ;
label define HALLAGE2  99 "NEVER USED/NO ANSWER" ;
label define HERAGE2   99 "NEVER USED/NO ANSWER" ;
label define STIMAGE2  99 "NEVER USED/NO ANSWER" ;
label define SEDAGE2   99 "NEVER USED/NO ANSWER" ;
label define TRANAGE2  99 "NEVER USED/NO ANSWER" ;
label define ANALAGE2  99 "LEGITIMATE SKIP/NO ANSWER" ;
label define ALCONLYL  0 "No" 1 "Yes" ;
label define ALCONLYY  0 "No" 1 "Yes" ;
label define ALCONLYM  0 "No" 1 "Yes" ;
label define ILLONLYL  0 "No" 1 "Yes" ;
label define ILLONLYY  0 "No" 1 "Yes" ;
label define ILLONLYM  0 "No" 1 "Yes" ;
label define MRJONLYL  0 "No" 1 "Yes" ;
label define MRJONLYY  0 "No" 1 "Yes" ;
label define MRJONLYM  0 "No" 1 "Yes" ;
label define PSYONLYL  0 "No" 1 "Yes" ;
label define PSYONLYY  0 "No" 1 "Yes" ;
label define PSYONLYM  0 "No" 1 "Yes" ;
label define OTHONLYL  0 "No" 1 "Yes" ;
label define OTHONLYY  0 "No" 1 "Yes" ;
label define OTHONLYM  0 "No" 1 "Yes" ;
label define ALCILLL   0 "No" 1 "Yes" ;
label define ALCILLY   0 "No" 1 "Yes" ;
label define ALCILLM   0 "No" 1 "Yes" ;
label define ALCMRJL   0 "No" 1 "Yes" ;
label define ALCMRJY   0 "No" 1 "Yes" ;
label define ALCMRJM   0 "No" 1 "Yes" ;
label define ALCPSYL   0 "No" 1 "Yes" ;
label define ALCPSYY   0 "No" 1 "Yes" ;
label define ALCPSYM   0 "No" 1 "Yes" ;
label define ALCOTHL   0 "No" 1 "Yes" ;
label define ALCOTHY   0 "No" 1 "Yes" ;
label define ALCOTHM   0 "No" 1 "Yes" ;
label define SUB1LIF   0 "No" 1 "Yes" ;
label define SUB2LIF   0 "No" 1 "Yes" ;
label define SUB3LIF   0 "No" 1 "Yes" ;
label define SUB1YR    0 "No" 1 "Yes" ;
label define SUB2YR    0 "No" 1 "Yes" ;
label define SUB3YR    0 "No" 1 "Yes" ;
label define SUB1MON   0 "No" 1 "Yes" ;
label define SUB2MON   0 "No" 1 "Yes" ;
label define SUB3MON   0 "No" 1 "Yes" ;
label define PSYAGE    99 "NEVER USED/NO ANSWER" ;
label define TRMTHLP2  0 "No" 1 "Yes" ;
label define DRNKHLP2  0 "No" 1 "Yes" ;
label define DRALHELP  0 "No" 1 "Yes" ;
label define BKLARCN2  0 "No" 1 "Yes" ;
label define BKBURGL2  0 "No" 1 "Yes" ;
label define BKAGASL2  0 "No" 1 "Yes" ;
label define BKSMASL2  0 "No" 1 "Yes" ;
label define BKMVTHF2  0 "No" 1 "Yes" ;
label define BKROB2    0 "No" 1 "Yes" ;
label define BKRAPE2   0 "No" 1 "Yes" ;
label define BKMURDE2  0 "No" 1 "Yes" ;
label define BKARSON2  0 "No" 1 "Yes" ;
label define BKDRVIN2  0 "No" 1 "Yes" ;
label define BKDRUNK2  0 "No" 1 "Yes" ;
label define BKDRUG2   0 "No" 1 "Yes" ;
label define BKPROS2   0 "No" 1 "Yes" ;
label define DRUNKYR2  1 "Yes" 2 "No" ;
label define FERTAGE   1 "Women ages 15-25" 2 "Women ages 26-44"
                       99 "Men/women 12-14, 45+" ;
label define PREG3     1 "Pregnant" 2 "Not pregnant" 99 "Otherwise" ;
label define TRIMEST2  1 "1st 3 mos of pregnancy" 2 "2nd 3 mos of pregnancy"
                       3 "Last 3 mos of pregnancy" 99 "Otherwise" ;
label define RSKCIG    0 "No" 1 "Yes" 99 "MISSING" ;
label define RSKMJ1    0 "No" 1 "Yes" 99 "MISSING" ;
label define RSKMJ2    0 "No" 1 "Yes" 99 "MISSING" ;
label define RSKCOC1   0 "No" 1 "Yes" 99 "MISSING" ;
label define RSKCOC2   0 "No" 1 "Yes" 99 "MISSING" ;
label define RSKALC1   0 "No" 1 "Yes" 99 "MISSING" ;
label define RSKALC2   0 "No" 1 "Yes" 99 "MISSING" ;
label define MARUSE    1 "Less than 12 days" 2 "12-50 days" 3 "51-300 days"
                       4 "More than 300 days" 5 "Did not use in past year" ;
label define COCUSE    1 "Less than 12 days" 2 "12-50 days" 3 "51-300 days"
                       4 "More than 300 days" 5 "Has not used in past year" ;
label define ALCUSE    1 "Less than 12 days" 2 "12-50 days" 3 "51-300 days"
                       4 "More than 300 days" 5 "HAS NOT USED IN PAST YEAR" ;
label define TOTPROB   999.0000 "BLANK" ;
label define INT       99.0000 "BLANK" ;
label define EXT       99 "BLANK" ;
label define PR_EMOT   0 "No" 1 "Yes" 99 "BLANK" ;
label define PR_BEHAV  0 "No" 1 "Yes" 99 "BLANK" ;
label define PR_TOTAL  0 "No" 1 "Yes" 99 "BLANK" ;
label define PR_WD     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_SC     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_AD     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_SP     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_TP     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_AP     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_DB     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define PR_AB     0 "No" 1 "Yes" 99 "BLANK/NO ANSWER" ;
label define ANY4MENT  0 "Did not have in past year" 1 "Had in past year"
                       99 "CHILDREN AGE 12-17" ;
label define ALCDRIV   0 "No" 1 "Yes" ;
label define MRJDRIV   0 "No" 1 "Yes" ;
label define AGECAT3   1 "12-13" 2 "14-15" 3 "16-17" 4 "18-20" 5 "21-25"
                       6 "26-29" 7 "30-34" 8 "35-39" 9 "40-44" 10 "45-49"
                       11 "50-102" ;
label define DRUNKYR3  0 "No" 1 "Yes" 99 "CHILDREN AGE 12-17" ;
label define HERNEED2  0 "No" 1 "Yes" ;
label define RSKSELL2  0 "No" 1 "Yes" ;
label define SEXYR     0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define RELNOW    0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define HIVTEST   0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define CDALWAYS  0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define CDSOME    0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define CDNEVER   0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define YRDIFPP1  0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define YRDIFPP2  0 "No" 1 "Yes" 99 "LEGITIMATE SKIP" ;
label define EHOUR     94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define EMIN      94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace VESTR = . if (VESTR >= 9981 )
replace SKPMARTL = . if (SKPMARTL == 9)
replace MARITAL = . if (MARITAL >= 81 )
replace NOMARR = . if (NOMARR >= 81 )
replace SKPMILT = . if (SKPMILT == 9)
replace SERVICE = . if (SERVICE >= 81 )
replace MILSTAT = . if (MILSTAT >= 81 )
replace EDUC = . if (EDUC >= 81 )
replace DIPLOMA = . if (DIPLOMA >= 81 )
replace ENROLLD = . if (ENROLLD >= 81 )
replace WORKSTAT = . if (WORKSTAT >= 81 )
replace HTININCH = . if (HTININCH >= 981 )
replace POUNDS = . if (POUNDS >= 981 )
replace HEALTH = . if (HEALTH >= 81 )
replace CIGEVER = . if (CIGEVER >= 81 )
replace CIGTRY = . if (CIGTRY >= 981 )
replace CIGTOT = . if (CIGTOT >= 81 )
replace CIGREC = . if (CIGREC >= 81 )
replace CIG30USE = . if (CIG30USE >= 81 )
replace AVCIG = . if (AVCIG >= 81 )
replace CIG30WOK = . if (CIG30WOK >= 81 )
replace CIGEVYDA = . if (CIGEVYDA >= 81 )
replace CIGAGE = . if (CIGAGE >= 981 )
replace CIGYRS = . if (CIGYRS >= 981 )
replace SNUFEVER = . if (SNUFEVER >= 81 )
replace SNUFREC = . if (SNUFREC >= 81 )
replace SKPALCRD = . if (SKPALCRD >= 81 )
replace ALCREAD = . if (ALCREAD >= 81 )
replace ALCEVER = . if (ALCEVER == 9)
replace ALCTRY = . if (ALCTRY >= 981 )
replace ALCREC = . if (ALCREC >= 81 )
replace ALCPAT = . if (ALCPAT >= 81 )
replace DRUNKYR = . if (DRUNKYR >= 81 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace NODR30A = . if (NODR30A >= 81 )
replace DR5DAY = . if (DR5DAY >= 81 )
replace MJEVER = . if (MJEVER == 9)
replace MJAGE = . if (MJAGE >= 981 )
replace MJTOT = . if (MJTOT >= 81 )
replace MJREC = . if (MJREC >= 81 )
replace MJYRFREQ = . if (MJYRFREQ >= 81 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace SKPCOCRD = . if (SKPCOCRD >= 81 )
replace COCREAD = . if (COCREAD >= 81 )
replace COCEVER = . if (COCEVER == 9)
replace COCAGE = . if (COCAGE >= 981 )
replace COCTOT = . if (COCTOT >= 81 )
replace COCREC = . if (COCREC >= 81 )
replace COCYRFRQ = . if (COCYRFRQ >= 81 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace SKPCRKRD = . if (SKPCRKRD >= 81 )
replace CRKREAD = . if (CRKREAD >= 81 )
replace CRKEVER = . if (CRKEVER >= 81 )
replace CRKAGE = . if (CRKAGE >= 981 )
replace CRKTOT = . if (CRKTOT >= 81 )
replace CRAKREC = . if (CRAKREC >= 81 )
replace CRKYRFRQ = . if (CRKYRFRQ >= 81 )
replace CRKUS30A = . if (CRKUS30A >= 81 )
replace SKPHERRD = . if (SKPHERRD >= 81 )
replace HERREAD = . if (HERREAD >= 81 )
replace HEREVER = . if (HEREVER >= 81 )
replace HERAGE = . if (HERAGE >= 981 )
replace HERTOT = . if (HERTOT >= 81 )
replace HERREC = . if (HERREC >= 81 )
replace HERYRFRQ = . if (HERYRFRQ >= 81 )
replace HER30USE = . if (HER30USE >= 81 )
replace SKPHALRD = . if (SKPHALRD >= 81 )
replace HALREAD = . if (HALREAD >= 81 )
replace LSD = . if (LSD >= 81 )
replace PCP = . if (PCP >= 81 )
replace PEYOTE = . if (PEYOTE >= 81 )
replace MESC = . if (MESC >= 81 )
replace PSILCY = . if (PSILCY >= 81 )
replace ECSTASY = . if (ECSTASY >= 81 )
replace HALDKNAM = . if (HALDKNAM >= 81 )
replace HALNOLST = . if (HALNOLST >= 81 )
replace HALNEWA = . if (HALNEWA >= 9981 )
replace HALNEWB = . if (HALNEWB >= 9981 )
replace HALNEWC = . if (HALNEWC >= 9981 )
replace HALNEWD = . if (HALNEWD >= 9981 )
replace HALNEWE = . if (HALNEWE >= 9981 )
replace HALLAGE = . if (HALLAGE >= 981 )
replace HALLTOT = . if (HALLTOT >= 81 )
replace HALLREC = . if (HALLREC >= 81 )
replace HALYRFRQ = . if (HALYRFRQ >= 81 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace LSDREC = . if (LSDREC >= 81 )
replace PCPREC = . if (PCPREC >= 81 )
replace SKPINHRD = . if (SKPINHRD >= 81 )
replace INHREAD = . if (INHREAD >= 81 )
replace AMYLNIT = . if (AMYLNIT >= 81 )
replace CLEFLU = . if (CLEFLU >= 81 )
replace GAS = . if (GAS >= 81 )
replace GLUE = . if (GLUE >= 81 )
replace ETHER = . if (ETHER >= 81 )
replace SOLVENT = . if (SOLVENT >= 81 )
replace LGAS = . if (LGAS >= 81 )
replace NITOXID = . if (NITOXID >= 81 )
replace SPPAINT = . if (SPPAINT >= 81 )
replace AEROS = . if (AEROS >= 81 )
replace INHDKNAM = . if (INHDKNAM >= 81 )
replace INHNOLST = . if (INHNOLST >= 81 )
replace INHNEWA = . if (INHNEWA >= 9981 )
replace INHNEWB = . if (INHNEWB >= 9981 )
replace INHNEWC = . if (INHNEWC >= 9981 )
replace INHNEWD = . if (INHNEWD >= 9981 )
replace INHNEWE = . if (INHNEWE >= 9981 )
replace INHAGE = . if (INHAGE >= 981 )
replace INHTOT = . if (INHTOT >= 81 )
replace INHREC = . if (INHREC >= 81 )
replace INHYRFRQ = . if (INHYRFRQ >= 81 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace SKPANLRD = . if (SKPANLRD >= 81 )
replace ANLREAD = . if (ANLREAD >= 81 )
replace CODEINE = . if (CODEINE >= 81 )
replace DARVON = . if (DARVON >= 81 )
replace DEMEROL = . if (DEMEROL >= 81 )
replace DILAUD = . if (DILAUD >= 81 )
replace METHDON = . if (METHDON >= 81 )
replace MORPHINE = . if (MORPHINE >= 81 )
replace PERCODAN = . if (PERCODAN >= 81 )
replace TALWIN = . if (TALWIN >= 81 )
replace TYLCOD = . if (TYLCOD >= 81 )
replace ANLDKNAM = . if (ANLDKNAM >= 81 )
replace ANLNOLST = . if (ANLNOLST >= 81 )
replace ANALNEWA = . if (ANALNEWA >= 9981 )
replace ANALNEWB = . if (ANALNEWB >= 9981 )
replace ANALNEWC = . if (ANALNEWC >= 9981 )
replace ANALNEWD = . if (ANALNEWD >= 9981 )
replace ANALNEWE = . if (ANALNEWE >= 9981 )
replace ANALNONE = . if (ANALNONE >= 81 )
replace ANALAGE = . if (ANALAGE >= 981 )
replace ANALTOT = . if (ANALTOT >= 81 )
replace ANALREC = . if (ANALREC >= 81 )
replace ANLYRFRQ = . if (ANLYRFRQ >= 81 )
replace SKPTRNRD = . if (SKPTRNRD >= 81 )
replace TRNREAD = . if (TRNREAD >= 81 )
replace ATARAX = . if (ATARAX >= 81 )
replace ATIVAN = . if (ATIVAN >= 81 )
replace DIAZEPAM = . if (DIAZEPAM >= 81 )
replace LIBRIUM = . if (LIBRIUM >= 81 )
replace TRANXENE = . if (TRANXENE >= 81 )
replace VALIUM = . if (VALIUM >= 81 )
replace XANAX = . if (XANAX >= 81 )
replace TRDKNAM = . if (TRDKNAM >= 81 )
replace TRNOLST = . if (TRNOLST >= 81 )
replace TRNEWA = . if (TRNEWA >= 9981 )
replace TRNEWB = . if (TRNEWB >= 9981 )
replace TRNEWC = . if (TRNEWC >= 9981 )
replace TRNEWD = . if (TRNEWD >= 9981 )
replace TRNEWE = . if (TRNEWE >= 9981 )
replace NOTRANQ = . if (NOTRANQ >= 81 )
replace TRANAGE = . if (TRANAGE >= 981 )
replace TRANTOT = . if (TRANTOT >= 81 )
replace TRANREC = . if (TRANREC >= 81 )
replace TRNYRFRQ = . if (TRNYRFRQ >= 81 )
replace SKPSTMRD = . if (SKPSTMRD >= 81 )
replace STMREAD = . if (STMREAD >= 81 )
replace BENZ = . if (BENZ >= 81 )
replace BIPHET = . if (BIPHET >= 81 )
replace DEXAMYL = . if (DEXAMYL >= 81 )
replace DEXED = . if (DEXED >= 81 )
replace FASTIN = . if (FASTIN >= 81 )
replace IONAMIN = . if (IONAMIN >= 81 )
replace METHAMP = . if (METHAMP >= 81 )
replace METHI = . if (METHI >= 81 )
replace PRELUDIN = . if (PRELUDIN >= 81 )
replace STMDKNAM = . if (STMDKNAM >= 81 )
replace STMNOLST = . if (STMNOLST >= 81 )
replace STIMNEWA = . if (STIMNEWA >= 9981 )
replace STIMNEWB = . if (STIMNEWB >= 9981 )
replace STIMNEWC = . if (STIMNEWC >= 9981 )
replace STIMNEWD = . if (STIMNEWD >= 9981 )
replace STIMNEWE = . if (STIMNEWE >= 9981 )
replace NOSTIMS = . if (NOSTIMS >= 81 )
replace STIMAGE = . if (STIMAGE >= 981 )
replace STIMTOT = . if (STIMTOT >= 81 )
replace STIMREC = . if (STIMREC >= 81 )
replace STMYRFRQ = . if (STMYRFRQ >= 81 )
replace SKPSEDRD = . if (SKPSEDRD >= 81 )
replace SEDREAD = . if (SEDREAD >= 81 )
replace DALMANE = . if (DALMANE >= 81 )
replace HALCION = . if (HALCION >= 81 )
replace METHAQ = . if (METHAQ >= 81 )
replace NEMBUTAL = . if (NEMBUTAL >= 81 )
replace PHENOBAR = . if (PHENOBAR >= 81 )
replace PLACIDYL = . if (PLACIDYL >= 81 )
replace SECONAL = . if (SECONAL >= 81 )
replace TUINAL = . if (TUINAL >= 81 )
replace SEDDKNAM = . if (SEDDKNAM >= 81 )
replace SEDNOLST = . if (SEDNOLST >= 81 )
replace SEDNEWA = . if (SEDNEWA >= 9981 )
replace SEDNEWB = . if (SEDNEWB >= 9981 )
replace SEDNEWC = . if (SEDNEWC >= 9981 )
replace SEDNEWD = . if (SEDNEWD >= 9981 )
replace SEDNEWE = . if (SEDNEWE >= 9981 )
replace NOSEDAT = . if (NOSEDAT >= 81 )
replace SEDAGE = . if (SEDAGE >= 981 )
replace SEDTOT = . if (SEDTOT >= 81 )
replace SEDREC = . if (SEDREC >= 81 )
replace SEDYRFRQ = . if (SEDYRFRQ >= 81 )
replace BIRMONTH = . if (BIRMONTH >= 81 )
replace BIRYEAR = . if (BIRYEAR >= 9981 )
replace IIAGE = . if (IIAGE == 9)
replace IRSEX = . if (IRSEX == 9)
replace IISEX = . if (IISEX == 9)
replace IRRACE = . if (IRRACE == 9)
replace IIRACE = . if (IIRACE == 9)
replace IRHOIND = . if (IRHOIND == 9)
replace IIHOIND = . if (IIHOIND == 9)
replace IRHOGRP = . if (IRHOGRP >= 81 )
replace IIHOGRP = . if (IIHOGRP == 9)
replace IRHOGRP2 = . if (IRHOGRP2 >= 81 )
replace IIHOGRP2 = . if (IIHOGRP2 == 9)
replace IRMARIT = . if (IRMARIT >= 81 )
replace IIMARIT = . if (IIMARIT == 9)
replace IREDUC = . if (IREDUC >= 81 )
replace IIEDUC = . if (IIEDUC == 9)
replace IRHSGRAD = . if (IRHSGRAD == 9)
replace IIHSGRAD = . if (IIHSGRAD == 9)
replace IRWORKST = . if (IRWORKST >= 81 )
replace IIWORKST = . if (IIWORKST == 9)
replace IRCIGRC = . if (IRCIGRC == 9)
replace IICIGRC = . if (IICIGRC == 9)
replace IROTBRC = . if (IROTBRC == 9)
replace IIOTBRC = . if (IIOTBRC == 9)
replace IRALCRC = . if (IRALCRC == 9)
replace IIALCRC = . if (IIALCRC == 9)
replace IRMJRC = . if (IRMJRC == 9)
replace IIMJRC = . if (IIMJRC == 9)
replace IRCOCRC = . if (IRCOCRC == 9)
replace IICOCRC = . if (IICOCRC == 9)
replace IRCRKRC = . if (IRCRKRC == 9)
replace IICRKRC = . if (IICRKRC == 9)
replace IRHERRC = . if (IRHERRC == 9)
replace IIHERRC = . if (IIHERRC == 9)
replace IRHALRC = . if (IRHALRC == 9)
replace IIHALRC = . if (IIHALRC == 9)
replace IRLSDRC = . if (IRLSDRC == 9)
replace IILSDRC = . if (IILSDRC == 9)
replace IRPCPRC = . if (IRPCPRC == 9)
replace IIPCPRC = . if (IIPCPRC == 9)
replace IRINHRC = . if (IRINHRC == 9)
replace IIINHRC = . if (IIINHRC == 9)
replace IRANLRC = . if (IRANLRC == 9)
replace IIANLRC = . if (IIANLRC == 9)
replace IRTRNRC = . if (IRTRNRC == 9)
replace IITRNRC = . if (IITRNRC == 9)
replace IRSTMRC = . if (IRSTMRC == 9)
replace IISTMRC = . if (IISTMRC == 9)
replace IRSEDRC = . if (IRSEDRC == 9)
replace IISEDRC = . if (IISEDRC == 9)
replace IRALCFQ = . if (IRALCFQ >= 81 )
replace IIALCFQ = . if (IIALCFQ == 9)
replace IRMJFQ = . if (IRMJFQ >= 81 )
replace IIMJFQ = . if (IIMJFQ == 9)
replace IRCOCFQ = . if (IRCOCFQ >= 81 )
replace IICOCFQ = . if (IICOCFQ == 9)
replace IRCRKFQ = . if (IRCRKFQ >= 81 )
replace IICRKFQ = . if (IICRKFQ == 9)
replace IRHERFQ = . if (IRHERFQ >= 81 )
replace IIHERFQ = . if (IIHERFQ == 9)
replace IRHALFQ = . if (IRHALFQ >= 81 )
replace IIHALFQ = . if (IIHALFQ == 9)
replace IRINHFQ = . if (IRINHFQ >= 81 )
replace IIINHFQ = . if (IIINHFQ == 9)
replace IRANLFQ = . if (IRANLFQ >= 81 )
replace IIANLFQ = . if (IIANLFQ == 9)
replace IRTRNFQ = . if (IRTRNFQ >= 81 )
replace IITRNFQ = . if (IITRNFQ == 9)
replace IRSTMFQ = . if (IRSTMFQ >= 81 )
replace IISTMFQ = . if (IISTMFQ == 9)
replace IRSEDFQ = . if (IRSEDFQ >= 81 )
replace IISEDFQ = . if (IISEDFQ == 9)
replace CATAGE = . if (CATAGE == 9)
replace CATAG2 = . if (CATAG2 == 9)
replace CATAG3 = . if (CATAG3 == 9)
replace RACE = . if (RACE == 9)
replace HISPRACE = . if (HISPRACE == 9)
replace EDUCCAT2 = . if (EDUCCAT2 == 9)
replace EMPSTAT2 = . if (EMPSTAT2 == 9)
replace MARISTAT = . if (MARISTAT == 9)
replace NOTMAR = . if (NOTMAR == 9)
replace CIGFLAG = . if (CIGFLAG == 9)
replace CIGYR = . if (CIGYR == 9)
replace CIGMON = . if (CIGMON == 9)
replace SMKFLAG = . if (SMKFLAG == 9)
replace SMKYR = . if (SMKYR == 9)
replace SMKMON = . if (SMKMON == 9)
replace ALCFLAG = . if (ALCFLAG == 9)
replace ALCYR = . if (ALCYR == 9)
replace ALCMON = . if (ALCMON == 9)
replace MRJFLAG = . if (MRJFLAG == 9)
replace MRJYR = . if (MRJYR == 9)
replace MRJMON = . if (MRJMON == 9)
replace COCFLAG = . if (COCFLAG == 9)
replace COCYR = . if (COCYR == 9)
replace COCMON = . if (COCMON == 9)
replace CRKFLAG = . if (CRKFLAG == 9)
replace CRKYR = . if (CRKYR == 9)
replace CRKMON = . if (CRKMON == 9)
replace HERFLAG = . if (HERFLAG == 9)
replace HERYR = . if (HERYR == 9)
replace HERMON = . if (HERMON == 9)
replace HALFLAG = . if (HALFLAG == 9)
replace HALYR = . if (HALYR == 9)
replace HALMON = . if (HALMON == 9)
replace LSDFLAG = . if (LSDFLAG == 9)
replace LSDYR = . if (LSDYR == 9)
replace LSDMON = . if (LSDMON == 9)
replace PCPFLAG = . if (PCPFLAG == 9)
replace PCPYR = . if (PCPYR == 9)
replace PCPMON = . if (PCPMON == 9)
replace INHFLAG = . if (INHFLAG == 9)
replace INHYR = . if (INHYR == 9)
replace INHMON = . if (INHMON == 9)
replace ANLFLAG = . if (ANLFLAG == 9)
replace ANLYR = . if (ANLYR == 9)
replace ANLMON = . if (ANLMON == 9)
replace TRQFLAG = . if (TRQFLAG == 9)
replace TRQYR = . if (TRQYR == 9)
replace TRQMON = . if (TRQMON == 9)
replace STMFLAG = . if (STMFLAG == 9)
replace STMYR = . if (STMYR == 9)
replace STMMON = . if (STMMON == 9)
replace SEDFLAG = . if (SEDFLAG == 9)
replace SEDYR = . if (SEDYR == 9)
replace SEDMON = . if (SEDMON == 9)
replace ALCYRF = . if (ALCYRF == 9)
replace ALCMONF = . if (ALCMONF == 9)
replace ALCWKF = . if (ALCWKF == 9)
replace ALCOCCF = . if (ALCOCCF == 9)
replace ALCDLYF = . if (ALCDLYF == 9)
replace MRJYRF = . if (MRJYRF == 9)
replace MRJMONF = . if (MRJMONF == 9)
replace MRJWKF = . if (MRJWKF == 9)
replace MRJOCCF = . if (MRJOCCF == 9)
replace MRJDLYF = . if (MRJDLYF == 9)
replace COCYRF = . if (COCYRF == 9)
replace COCMONF = . if (COCMONF == 9)
replace COCWKF = . if (COCWKF == 9)
replace COCOCCF = . if (COCOCCF == 9)
replace COCDLYF = . if (COCDLYF == 9)
replace CRKYRF = . if (CRKYRF == 9)
replace CRKMONF = . if (CRKMONF == 9)
replace CRKWKF = . if (CRKWKF == 9)
replace CRKOCCF = . if (CRKOCCF == 9)
replace CRKDLYF = . if (CRKDLYF == 9)
replace HERYRF = . if (HERYRF == 9)
replace HERMONF = . if (HERMONF == 9)
replace HERWKF = . if (HERWKF == 9)
replace HEROCCF = . if (HEROCCF == 9)
replace HERDLYF = . if (HERDLYF == 9)
replace HALYRF = . if (HALYRF == 9)
replace HALMONF = . if (HALMONF == 9)
replace HALWKF = . if (HALWKF == 9)
replace HALOCCF = . if (HALOCCF == 9)
replace HALDLYF = . if (HALDLYF == 9)
replace INHYRF = . if (INHYRF == 9)
replace INHMONF = . if (INHMONF == 9)
replace INHWKF = . if (INHWKF == 9)
replace INHOCCF = . if (INHOCCF == 9)
replace INHDLYF = . if (INHDLYF == 9)
replace ANLYRF = . if (ANLYRF == 9)
replace ANLMONF = . if (ANLMONF == 9)
replace ANLWKF = . if (ANLWKF == 9)
replace ANLOCCF = . if (ANLOCCF == 9)
replace ANLDLYF = . if (ANLDLYF == 9)
replace TRQYRF = . if (TRQYRF == 9)
replace TRQMONF = . if (TRQMONF == 9)
replace TRQWKF = . if (TRQWKF == 9)
replace TRQOCCF = . if (TRQOCCF == 9)
replace TRQDLYF = . if (TRQDLYF == 9)
replace STMYRF = . if (STMYRF == 9)
replace STMMONF = . if (STMMONF == 9)
replace STMWKF = . if (STMWKF == 9)
replace STMOCCF = . if (STMOCCF == 9)
replace STMDLYF = . if (STMDLYF == 9)
replace SEDYRF = . if (SEDYRF == 9)
replace SEDMONF = . if (SEDMONF == 9)
replace SEDWKF = . if (SEDWKF == 9)
replace SEDOCCF = . if (SEDOCCF == 9)
replace SEDDLYF = . if (SEDDLYF == 9)
replace PSYFLAG2 = . if (PSYFLAG2 == 9)
replace PSYYR2 = . if (PSYYR2 == 9)
replace PSYMON2 = . if (PSYMON2 == 9)
replace SUMFLAG = . if (SUMFLAG == 9)
replace SUMYR = . if (SUMYR == 9)
replace SUMMON = . if (SUMMON == 9)
replace MJOFLAG = . if (MJOFLAG == 9)
replace MJOYR2 = . if (MJOYR2 == 9)
replace MJOMON2 = . if (MJOMON2 == 9)
replace IEMFLAG = . if (IEMFLAG == 9)
replace IEMYR = . if (IEMYR == 9)
replace IEMMON = . if (IEMMON == 9)
replace BINGEDRK = . if (BINGEDRK == 9)
replace HVYDRK2 = . if (HVYDRK2 == 9)
replace BINGEHVY = . if (BINGEHVY == 9)
replace PEYOTE2 = . if (PEYOTE2 == 9)
replace MESC2 = . if (MESC2 == 9)
replace PSILCY2 = . if (PSILCY2 == 9)
replace ECSTASY2 = . if (ECSTASY2 == 9)
replace METHAMP2 = . if (METHAMP2 == 9)
replace HERSMOK2 = . if (HERSMOK2 == 9)
replace HERSNIF2 = . if (HERSNIF2 == 9)
replace AMYLNIT2 = . if (AMYLNIT2 == 9)
replace CLEFLU2 = . if (CLEFLU2 == 9)
replace GAS2 = . if (GAS2 == 9)
replace GLUE2 = . if (GLUE2 == 9)
replace ETHER2 = . if (ETHER2 == 9)
replace SOLVENT2 = . if (SOLVENT2 == 9)
replace LGAS2 = . if (LGAS2 == 9)
replace NITOXID2 = . if (NITOXID2 == 9)
replace SPPAINT2 = . if (SPPAINT2 == 9)
replace AEROS2 = . if (AEROS2 == 9)
replace CG04 = . if (CG04 >= 81 )
replace CG12 = . if (CG12 >= 81 )
replace AL03 = . if (AL03 >= 81 )
replace AL04 = . if (AL04 >= 81 )
replace MJ04 = . if (MJ04 >= 81 )
replace MJ05 = . if (MJ05 >= 81 )
replace CC04 = . if (CC04 >= 81 )
replace CC05 = . if (CC05 >= 81 )
replace CK04 = . if (CK04 >= 81 )
replace CK05 = . if (CK05 >= 81 )
replace HE04 = . if (HE04 >= 81 )
replace HE05 = . if (HE05 >= 81 )
replace LS04 = . if (LS04 >= 81 )
replace LS05 = . if (LS05 >= 81 )
replace LS07 = . if (LS07 >= 81 )
replace LS08 = . if (LS08 >= 81 )
replace IN04 = . if (IN04 >= 81 )
replace IN05 = . if (IN05 >= 81 )
replace PK04 = . if (PK04 >= 81 )
replace PK05 = . if (PK05 >= 81 )
replace TR04 = . if (TR04 >= 81 )
replace TR05 = . if (TR05 >= 81 )
replace ST04 = . if (ST04 >= 81 )
replace ST05 = . if (ST05 >= 81 )
replace SE04 = . if (SE04 >= 81 )
replace SE05 = . if (SE05 >= 81 )
replace SKPSDRD = . if (SKPSDRD >= 81 )
replace SDREAD = . if (SDREAD >= 81 )
replace HRANYFRM = . if (HRANYFRM >= 81 )
replace HERSMOKE = . if (HERSMOKE >= 81 )
replace HRSMKREC = . if (HRSMKREC >= 81 )
replace HERSNIFF = . if (HERSNIFF >= 81 )
replace HRSNFREC = . if (HRSNFREC >= 81 )
replace GNNDLLIF = . if (GNNDLLIF >= 81 )
replace COCNEEDL = . if (COCNEEDL >= 81 )
replace CONDLREC = . if (CONDLREC >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 81 )
replace HRNDLREC = . if (HRNDLREC >= 81 )
replace STNEEDLE = . if (STNEEDLE >= 81 )
replace STNDLREC = . if (STNDLREC >= 81 )
replace GNNDREUS = . if (GNNDREUS >= 81 )
replace GNNDLSH1 = . if (GNNDLSH1 >= 81 )
replace GNNDCLEN = . if (GNNDCLEN >= 81 )
replace GNNDLSH2 = . if (GNNDLSH2 >= 81 )
replace GNNDGET = . if (GNNDGET >= 81 )
replace GNNDGTSP = . if (GNNDGTSP >= 81 )
replace SKPRSKRD = . if (SKPRSKRD >= 81 )
replace RSKREAD = . if (RSKREAD >= 81 )
replace RSKPKCIG = . if (RSKPKCIG >= 81 )
replace RSKMJOCC = . if (RSKMJOCC >= 81 )
replace RSKMJREG = . if (RSKMJREG >= 81 )
replace RKCOCOCC = . if (RKCOCOCC >= 81 )
replace RKCOCREG = . if (RKCOCREG >= 81 )
replace RK5DRINK = . if (RK5DRINK >= 81 )
replace RSKBINGE = . if (RSKBINGE >= 81 )
replace RSKDIFMJ = . if (RSKDIFMJ >= 81 )
replace RKDIFCOC = . if (RKDIFCOC >= 81 )
replace RKDIFCRK = . if (RKDIFCRK >= 81 )
replace RKDIFHER = . if (RKDIFHER >= 81 )
replace RSKSELL = . if (RSKSELL >= 81 )
replace SKPDRGRD = . if (SKPDRGRD >= 81 )
replace DRGREAD = . if (DRGREAD >= 81 )
replace USEDCIG = . if (USEDCIG >= 81 )
replace USEDALC = . if (USEDALC >= 81 )
replace USEDMRJ = . if (USEDMRJ >= 81 )
replace USEDCOC = . if (USEDCOC >= 81 )
replace USEDHER = . if (USEDHER >= 81 )
replace USEDHAL = . if (USEDHAL >= 81 )
replace USEDINH = . if (USEDINH >= 81 )
replace USEDANL = . if (USEDANL >= 81 )
replace USEDTRN = . if (USEDTRN >= 81 )
replace USEDSTM = . if (USEDSTM >= 81 )
replace USEDSED = . if (USEDSED >= 81 )
replace NODRUGYR = . if (NODRUGYR >= 81 )
replace GRTMCIG = . if (GRTMCIG >= 81 )
replace GRTMALC = . if (GRTMALC >= 81 )
replace GRTMMRJ = . if (GRTMMRJ >= 81 )
replace GRTMCOC = . if (GRTMCOC >= 81 )
replace GRTMHER = . if (GRTMHER >= 81 )
replace GRTMHAL = . if (GRTMHAL >= 81 )
replace GRTMINH = . if (GRTMINH >= 81 )
replace GRTMANL = . if (GRTMANL >= 81 )
replace GRTMTRN = . if (GRTMTRN >= 81 )
replace GRTMSTM = . if (GRTMSTM >= 81 )
replace GRTMSED = . if (GRTMSED >= 81 )
replace LAMTCIG = . if (LAMTCIG >= 81 )
replace LAMTALC = . if (LAMTALC >= 81 )
replace LAMTMRJ = . if (LAMTMRJ >= 81 )
replace LAMTCOC = . if (LAMTCOC >= 81 )
replace LAMTHER = . if (LAMTHER >= 81 )
replace LAMTHAL = . if (LAMTHAL >= 81 )
replace LAMTINH = . if (LAMTINH >= 81 )
replace LAMTANL = . if (LAMTANL >= 81 )
replace LAMTTRN = . if (LAMTTRN >= 81 )
replace LAMTSTM = . if (LAMTSTM >= 81 )
replace LAMTSED = . if (LAMTSED >= 81 )
replace BTOLCIG = . if (BTOLCIG >= 81 )
replace BTOLALC = . if (BTOLALC >= 81 )
replace BTOLMRJ = . if (BTOLMRJ >= 81 )
replace BTOLCOC = . if (BTOLCOC >= 81 )
replace BTOLHER = . if (BTOLHER >= 81 )
replace BTOLHAL = . if (BTOLHAL >= 81 )
replace BTOLINH = . if (BTOLINH >= 81 )
replace BTOLANL = . if (BTOLANL >= 81 )
replace BTOLTRN = . if (BTOLTRN >= 81 )
replace BTOLSTM = . if (BTOLSTM >= 81 )
replace BTOLSED = . if (BTOLSED >= 81 )
replace ACRDCIG = . if (ACRDCIG >= 81 )
replace ACRDALC = . if (ACRDALC >= 81 )
replace ACRDMRJ = . if (ACRDMRJ >= 81 )
replace ACRDCOC = . if (ACRDCOC >= 81 )
replace ACRDHER = . if (ACRDHER >= 81 )
replace ACRDHAL = . if (ACRDHAL >= 81 )
replace ACRDINH = . if (ACRDINH >= 81 )
replace ACRDANL = . if (ACRDANL >= 81 )
replace ACRDTRN = . if (ACRDTRN >= 81 )
replace ACRDSTM = . if (ACRDSTM >= 81 )
replace ACRDSED = . if (ACRDSED >= 81 )
replace EMPBCIG = . if (EMPBCIG >= 81 )
replace EMPBALC = . if (EMPBALC >= 81 )
replace EMPBMRJ = . if (EMPBMRJ >= 81 )
replace EMPBCOC = . if (EMPBCOC >= 81 )
replace EMPBHER = . if (EMPBHER >= 81 )
replace EMPBHAL = . if (EMPBHAL >= 81 )
replace EMPBINH = . if (EMPBINH >= 81 )
replace EMPBANL = . if (EMPBANL >= 81 )
replace EMPBTRN = . if (EMPBTRN >= 81 )
replace EMPBSTM = . if (EMPBSTM >= 81 )
replace EMPBSED = . if (EMPBSED >= 81 )
replace HLPBCIG = . if (HLPBCIG >= 81 )
replace HLPBALC = . if (HLPBALC >= 81 )
replace HLPBMRJ = . if (HLPBMRJ >= 81 )
replace HLPBCOC = . if (HLPBCOC >= 81 )
replace HLPBHER = . if (HLPBHER >= 81 )
replace HLPBHAL = . if (HLPBHAL >= 81 )
replace HLPBINH = . if (HLPBINH >= 81 )
replace HLPBANL = . if (HLPBANL >= 81 )
replace HLPBTRN = . if (HLPBTRN >= 81 )
replace HLPBSTM = . if (HLPBSTM >= 81 )
replace HLPBSED = . if (HLPBSED >= 81 )
replace UCDCIG = . if (UCDCIG >= 81 )
replace UCDALC = . if (UCDALC >= 81 )
replace UCDMRJ = . if (UCDMRJ >= 81 )
replace UCDCOC = . if (UCDCOC >= 81 )
replace UCDHER = . if (UCDHER >= 81 )
replace UCDHAL = . if (UCDHAL >= 81 )
replace UCDINH = . if (UCDINH >= 81 )
replace UCDANL = . if (UCDANL >= 81 )
replace UCDTRN = . if (UCDTRN >= 81 )
replace UCDSTM = . if (UCDSTM >= 81 )
replace UCDSED = . if (UCDSED >= 81 )
replace SKPSPTRD = . if (SKPSPTRD >= 81 )
replace SPTREAD = . if (SPTREAD >= 81 )
replace NDTXRCVD = . if (NDTXRCVD >= 81 )
replace NDTXNEED = . if (NDTXNEED >= 81 )
replace NDTXALC = . if (NDTXALC >= 81 )
replace NDTXMJ = . if (NDTXMJ >= 81 )
replace NDTXCOC = . if (NDTXCOC >= 81 )
replace NDTXHER = . if (NDTXHER >= 81 )
replace NDTXHAL = . if (NDTXHAL >= 81 )
replace NDTXINH = . if (NDTXINH >= 81 )
replace NDTXANL = . if (NDTXANL >= 81 )
replace NDTXTRAN = . if (NDTXTRAN >= 81 )
replace NDTXSTIM = . if (NDTXSTIM >= 81 )
replace NDTXSED = . if (NDTXSED >= 81 )
replace NDTXSOD = . if (NDTXSOD >= 81 )
replace NDTXDRG1 = . if (NDTXDRG1 >= 9981 )
replace NDTXDRG2 = . if (NDTXDRG2 >= 9981 )
replace NDTXDRG3 = . if (NDTXDRG3 >= 9981 )
replace NDTXDRG4 = . if (NDTXDRG4 >= 9981 )
replace NDTXDRG5 = . if (NDTXDRG5 >= 9981 )
replace NDTXSTEP = . if (NDTXSTEP >= 81 )
replace NDTXTRSP = . if (NDTXTRSP >= 81 )
replace NDTXTFAR = . if (NDTXTFAR >= 81 )
replace NDTXBDHR = . if (NDTXBDHR >= 81 )
replace NDTXOPEN = . if (NDTXOPEN >= 81 )
replace NDTXTYPE = . if (NDTXTYPE >= 81 )
replace NDTXMONY = . if (NDTXMONY >= 81 )
replace NDTXHCAP = . if (NDTXHCAP >= 81 )
replace NDTXTCMP = . if (NDTXTCMP >= 81 )
replace NDTXLANG = . if (NDTXLANG >= 81 )
replace NDTXSPSV = . if (NDTXSPSV >= 81 )
replace NDTXSOR = . if (NDTXSOR >= 81 )
replace NDTXRSC1 = . if (NDTXRSC1 >= 81 )
replace BOOKED = . if (BOOKED >= 81 )
replace NOBOOKYR = . if (NOBOOKYR >= 81 )
replace BKLARCNY = . if (BKLARCNY >= 81 )
replace BKBURGL = . if (BKBURGL >= 81 )
replace BKAGASLT = . if (BKAGASLT >= 81 )
replace BKSMASLT = . if (BKSMASLT >= 81 )
replace BKMVTHFT = . if (BKMVTHFT >= 81 )
replace BKROB = . if (BKROB >= 81 )
replace BKRAPE = . if (BKRAPE >= 81 )
replace BKMURDER = . if (BKMURDER >= 81 )
replace BKARSON = . if (BKARSON >= 81 )
replace BKDRVINF = . if (BKDRVINF >= 81 )
replace BKDRUNK = . if (BKDRUNK >= 81 )
replace BKDRUG = . if (BKDRUG >= 81 )
replace BKPROS = . if (BKPROS >= 81 )
replace BKVANDAL = . if (BKVANDAL >= 81 )
replace BKOTH = . if (BKOTH >= 81 )
replace BKOTHOFF = . if (BKOTHOFF >= 81 )
replace PROBATON = . if (PROBATON >= 81 )
replace PAROLE = . if (PAROLE >= 81 )
replace DRVALDR = . if (DRVALDR >= 81 )
replace DRIVEAL = . if (DRIVEAL >= 81 )
replace DRIVEDR = . if (DRIVEDR >= 81 )
replace SKPTMTRD = . if (SKPTMTRD >= 81 )
replace TMTREAD = . if (TMTREAD >= 81 )
replace TXEVER = . if (TXEVER >= 81 )
replace TXTIMELF = . if (TXTIMELF >= 975 )
replace TXYRFREQ = . if (TXYRFREQ >= 975 )
replace TXALHOSP = . if (TXALHOSP >= 81 )
replace TXALRFIN = . if (TXALRFIN >= 81 )
replace TXALRFOP = . if (TXALRFOP >= 81 )
replace TXALMHC = . if (TXALMHC >= 81 )
replace TXALEMRG = . if (TXALEMRG >= 81 )
replace TXALDOC = . if (TXALDOC >= 81 )
replace TXALJAIL = . if (TXALJAIL >= 81 )
replace TXALSHG = . if (TXALSHG >= 81 )
replace TXALSOP = . if (TXALSOP >= 81 )
replace TXALSP = . if (TXALSP >= 81 )
replace TXDRHOSP = . if (TXDRHOSP >= 81 )
replace TXDRFIN = . if (TXDRFIN >= 81 )
replace TXDRFOP = . if (TXDRFOP >= 81 )
replace TXDRMHC = . if (TXDRMHC >= 81 )
replace TXDREMRG = . if (TXDREMRG >= 81 )
replace TXDRDOC = . if (TXDRDOC >= 81 )
replace TXDRJAIL = . if (TXDRJAIL >= 81 )
replace TXDRSHG = . if (TXDRSHG >= 81 )
replace TXDRSOP = . if (TXDRSOP >= 81 )
replace TXDRSP = . if (TXDRSP >= 81 )
replace TXYREMRG = . if (TXYREMRG >= 975 )
replace TXADGREC = . if (TXADGREC >= 81 )
replace TXLTHOSP = . if (TXLTHOSP >= 81 )
replace TXLTRFIN = . if (TXLTRFIN >= 81 )
replace TXLTRFOP = . if (TXLTRFOP >= 81 )
replace TXLTMHC = . if (TXLTMHC >= 81 )
replace TXLTEMRG = . if (TXLTEMRG >= 81 )
replace TXLTDOC = . if (TXLTDOC >= 81 )
replace TXLTJAIL = . if (TXLTJAIL >= 81 )
replace TXLTSHG = . if (TXLTSHG >= 81 )
replace TXLTSOP = . if (TXLTSOP >= 81 )
replace TXLTSP = . if (TXLTSP >= 81 )
replace TXLTALC = . if (TXLTALC >= 81 )
replace TXLTMJ = . if (TXLTMJ >= 81 )
replace TXLTCOC = . if (TXLTCOC >= 81 )
replace TXLTHER = . if (TXLTHER >= 81 )
replace TXLTHAL = . if (TXLTHAL >= 81 )
replace TXLTINH = . if (TXLTINH >= 81 )
replace TXLTANL = . if (TXLTANL >= 81 )
replace TXLTRAN = . if (TXLTRAN >= 81 )
replace TXLTSTIM = . if (TXLTSTIM >= 81 )
replace TXLTSED = . if (TXLTSED >= 81 )
replace TXLTSOD = . if (TXLTSOD >= 81 )
replace TXLTA = . if (TXLTA >= 9981 )
replace TXLTB = . if (TXLTB >= 9981 )
replace TXLTC = . if (TXLTC >= 9981 )
replace TXLTD = . if (TXLTD >= 9981 )
replace TXLTE = . if (TXLTE >= 9981 )
replace TXDRGA = . if (TXDRGA >= 9981 )
replace TXDRGB = . if (TXDRGB >= 9981 )
replace TXDRGC = . if (TXDRGC >= 9981 )
replace TXDRGD = . if (TXDRGD >= 9981 )
replace TXDRGE = . if (TXDRGE >= 9981 )
replace TXOUTC = . if (TXOUTC >= 81 )
replace TXTIME = . if (TXTIME >= 9975 )
replace TXPDINS = . if (TXPDINS >= 81 )
replace TXPDCARE = . if (TXPDCARE >= 81 )
replace TXPDCAID = . if (TXPDCAID >= 81 )
replace TXPDSAVE = . if (TXPDSAVE >= 81 )
replace TXPDFMLY = . if (TXPDFMLY >= 81 )
replace TXPDEMPL = . if (TXPDEMPL >= 81 )
replace TXPDFREE = . if (TXPDFREE >= 81 )
replace TXPDSOS = . if (TXPDSOS >= 81 )
replace TXPDSP = . if (TXPDSP >= 81 )
replace TXENROLL = . if (TXENROLL >= 81 )
replace SKYCPBAN = . if (SKYCPBAN == 9)
replace SKPYCRD = . if (SKPYCRD >= 81 )
replace YCREAD = . if (YCREAD >= 81 )
replace YACTYNG = . if (YACTYNG >= 81 )
replace YALLERGY = . if (YALLERGY >= 81 )
replace YARGUE = . if (YARGUE >= 81 )
replace YASTHMA = . if (YASTHMA >= 81 )
replace YACOPPSX = . if (YACOPPSX >= 81 )
replace YLKANIML = . if (YLKANIML >= 81 )
replace YBRAG = . if (YBRAG >= 81 )
replace YTRBCONC = . if (YTRBCONC >= 81 )
replace YCNTHGTS = . if (YCNTHGTS >= 81 )
replace YTRBSIT = . if (YTRBSIT >= 81 )
replace YDPTADLT = . if (YDPTADLT >= 81 )
replace YFLONELY = . if (YFLONELY >= 81 )
replace YFLCONFU = . if (YFLCONFU >= 81 )
replace YCRYLOT = . if (YCRYLOT >= 81 )
replace YHONEST = . if (YHONEST >= 81 )
replace YMEANOTH = . if (YMEANOTH >= 81 )
replace YDAYDREM = . if (YDAYDREM >= 81 )
replace YTRYKLSF = . if (YTRYKLSF >= 81 )
replace YTRYATTN = . if (YTRYATTN >= 81 )
replace YDSTYTHG = . if (YDSTYTHG >= 81 )
replace YDSTYOTH = . if (YDSTYOTH >= 81 )
replace YDSBYPAR = . if (YDSBYPAR >= 81 )
replace YDSBYSCH = . if (YDSBYSCH >= 81 )
replace YDNTEATW = . if (YDNTEATW >= 81 )
replace YDNTKIDS = . if (YDNTKIDS >= 81 )
replace YDNTGLTY = . if (YDNTGLTY >= 81 )
replace YJEALOTH = . if (YJEALOTH >= 81 )
replace YHELPOTH = . if (YHELPOTH >= 81 )
replace YAFRPLAC = . if (YAFRPLAC >= 81 )
replace YAFRSCHL = . if (YAFRSCHL >= 81 )
replace YAFRBAD = . if (YAFRBAD >= 81 )
replace YFLPRFCT = . if (YFLPRFCT >= 81 )
replace YFLNOLOV = . if (YFLNOLOV >= 81 )
replace YFLGETME = . if (YFLGETME >= 81 )
replace YFLWTHLS = . if (YFLWTHLS >= 81 )
replace YACCHURT = . if (YACCHURT >= 81 )
replace YFIGHTS = . if (YFIGHTS >= 81 )
replace YGTEASED = . if (YGTEASED >= 81 )
replace YKIDSTRB = . if (YKIDSTRB >= 81 )
replace YHRVOICS = . if (YHRVOICS >= 81 )
replace YACTTNK = . if (YACTTNK >= 81 )
replace YALONE = . if (YALONE >= 81 )
replace YLIE = . if (YLIE >= 81 )
replace YBITNAIL = . if (YBITNAIL >= 81 )
replace YNERVOUS = . if (YNERVOUS >= 81 )
replace YBTWITCH = . if (YBTWITCH >= 81 )
replace YNGHTMAR = . if (YNGHTMAR >= 81 )
replace YNOTKIDS = . if (YNOTKIDS >= 81 )
replace YDOBETTR = . if (YDOBETTR >= 81 )
replace YANXIOUS = . if (YANXIOUS >= 81 )
replace YFLDIZZY = . if (YFLDIZZY >= 81 )
replace YFLGUILT = . if (YFLGUILT >= 81 )
replace YEATMUCH = . if (YEATMUCH >= 81 )
replace YFLTIRED = . if (YFLTIRED >= 81 )
replace YOVRWGHT = . if (YOVRWGHT >= 81 )
replace YACHES = . if (YACHES >= 81 )
replace YHEADACH = . if (YHEADACH >= 81 )
replace YNAUSEA = . if (YNAUSEA >= 81 )
replace YEYEPROB = . if (YEYEPROB >= 81 )
replace YRASHES = . if (YRASHES >= 81 )
replace YCRAMPS = . if (YCRAMPS >= 81 )
replace YVOMIT = . if (YVOMIT >= 81 )
replace YATTACK = . if (YATTACK >= 81 )
replace YPKBPART = . if (YPKBPART >= 81 )
replace YPFRNDLY = . if (YPFRNDLY >= 81 )
replace YTRYTHNG = . if (YTRYTHNG >= 81 )
replace YSCPOOR = . if (YSCPOOR >= 81 )
replace YCLUMSY = . if (YCLUMSY >= 81 )
replace YOLDKIDS = . if (YOLDKIDS >= 81 )
replace YYNGKIDS = . if (YYNGKIDS >= 81 )
replace YRFSTALK = . if (YRFSTALK >= 81 )
replace YREPACTN = . if (YREPACTN >= 81 )
replace YRUNHOME = . if (YRUNHOME >= 81 )
replace YSCREAM = . if (YSCREAM >= 81 )
replace YSECRET = . if (YSECRET >= 81 )
replace YSEETHNG = . if (YSEETHNG >= 81 )
replace YSLFCONS = . if (YSLFCONS >= 81 )
replace YSETFIRE = . if (YSETFIRE >= 81 )
replace YWELHNDS = . if (YWELHNDS >= 81 )
replace YSHOWOFF = . if (YSHOWOFF >= 81 )
replace YSHY = . if (YSHY >= 81 )
replace YSLPLESS = . if (YSLPLESS >= 81 )
replace YSLPMORE = . if (YSLPMORE >= 81 )
replace YGDIMAG = . if (YGDIMAG >= 81 )
replace YSPCHPRB = . if (YSPCHPRB >= 81 )
replace YSTDRGHT = . if (YSTDRGHT >= 81 )
replace YSTEALHO = . if (YSTEALHO >= 81 )
replace YSTEALPL = . if (YSTEALPL >= 81 )
replace YDNTNEED = . if (YDNTNEED >= 81 )
replace YDOSTRNG = . if (YDOSTRNG >= 81 )
replace YTHSTRNG = . if (YTHSTRNG >= 81 )
replace YSTUBORN = . if (YSTUBORN >= 81 )
replace YMOODS = . if (YMOODS >= 81 )
replace YENJOY = . if (YENJOY >= 81 )
replace YSUSPICS = . if (YSUSPICS >= 81 )
replace YDRTLANG = . if (YDRTLANG >= 81 )
replace YTHKKLSF = . if (YTHKKLSF >= 81 )
replace YLKLAUGH = . if (YLKLAUGH >= 81 )
replace YTALKMCH = . if (YTALKMCH >= 81 )
replace YTEASE = . if (YTEASE >= 81 )
replace YTEMPER = . if (YTEMPER >= 81 )
replace YTHNKSEX = . if (YTHNKSEX >= 81 )
replace YTHRTPEO = . if (YTHRTPEO >= 81 )
replace YLKHELP = . if (YLKHELP >= 81 )
replace YCONNEAT = . if (YCONNEAT >= 81 )
replace YTRBSLEP = . if (YTRBSLEP >= 81 )
replace YSKIPSCH = . if (YSKIPSCH >= 81 )
replace YNOENRGY = . if (YNOENRGY >= 81 )
replace YUNHAPPY = . if (YUNHAPPY >= 81 )
replace YLOUDER = . if (YLOUDER >= 81 )
replace YUSEDRUG = . if (YUSEDRUG >= 81 )
replace YFAIROTH = . if (YFAIROTH >= 81 )
replace YENJYJOK = . if (YENJYJOK >= 81 )
replace YLIFEASY = . if (YLIFEASY >= 81 )
replace YTRYHELP = . if (YTRYHELP >= 81 )
replace YWSOPPSX = . if (YWSOPPSX >= 81 )
replace YINVOTH = . if (YINVOTH >= 81 )
replace YWORRY = . if (YWORRY >= 81 )
replace SKPBDBAN = . if (SKPBDBAN >= 81 )
replace SKPPBRD = . if (SKPPBRD >= 81 )
replace PBREAD = . if (PBREAD >= 81 )
replace XSEXYR = . if (XSEXYR >= 81 )
replace XRELNOW = . if (XRELNOW >= 81 )
replace XRELYR = . if (XRELYR >= 81 )
replace XRELCDV = . if (XRELCDV >= 81 )
replace XRELCDA = . if (XRELCDA >= 81 )
replace XNRELYR = . if (XNRELYR >= 81 )
replace XNRELCDV = . if (XNRELCDV >= 81 )
replace XNRELCDA = . if (XNRELCDA >= 81 )
replace XYRDIFPP = . if (XYRDIFPP >= 81 )
replace XYRWTHMF = . if (XYRWTHMF >= 81 )
replace XYRHIV = . if (XYRHIV >= 81 )
replace XYRMONEY = . if (XYRMONEY >= 81 )
replace XYRDRUGS = . if (XYRDRUGS >= 81 )
replace XCDEVER = . if (XCDEVER >= 81 )
replace XCDLAST = . if (XCDLAST >= 81 )
replace XCDPREG = . if (XCDPREG >= 81 )
replace XCDSTD = . if (XCDSTD >= 81 )
replace XCDNMESS = . if (XCDNMESS >= 81 )
replace XCDOTRSN = . if (XCDOTRSN >= 81 )
replace XCDRSN1 = . if (XCDRSN1 >= 81 )
replace XNCDPREG = . if (XNCDPREG >= 81 )
replace XNCDMONO = . if (XNCDMONO >= 81 )
replace XNCDSTD = . if (XNCDSTD >= 81 )
replace XNCDOBC = . if (XNCDOBC >= 81 )
replace XNCDRELG = . if (XNCDRELG >= 81 )
replace XNCDPTNR = . if (XNCDPTNR >= 81 )
replace XNCDNA = . if (XNCDNA >= 81 )
replace XNCDHOW = . if (XNCDHOW >= 81 )
replace XNCDSAFE = . if (XNCDSAFE >= 81 )
replace XNCDORSN = . if (XNCDORSN >= 81 )
replace XNCDRSN1 = . if (XNCDRSN1 >= 81 )
replace XCDMOOD = . if (XCDMOOD >= 81 )
replace XCDRESP = . if (XCDRESP >= 81 )
replace XCDFEEL = . if (XCDFEEL >= 81 )
replace XCDTRST = . if (XCDTRST >= 81 )
replace XCDEMBR = . if (XCDEMBR >= 81 )
replace XCDCOST = . if (XCDCOST >= 81 )
replace XRELLAST = . if (XRELLAST >= 81 )
replace XLFBLOOD = . if (XLFBLOOD >= 81 )
replace XBLD385 = . if (XBLD385 >= 81 )
replace XLTBLDMO = . if (XLTBLDMO >= 81 )
replace XLTBLDYR = . if (XLTBLDYR >= 981 )
replace XHIVTEST = . if (XHIVTEST >= 81 )
replace XLTHIVMO = . if (XLTHIVMO >= 81 )
replace XLTHIVYR = . if (XLTHIVYR >= 981 )
replace XHIVRSLT = . if (XHIVRSLT >= 81 )
replace SKPDBRD = . if (SKPDBRD >= 81 )
replace DBREAD = . if (DBREAD >= 81 )
replace VDRVYR = . if (VDRVYR >= 81 )
replace VYRFREQ = . if (VYRFREQ >= 81 )
replace VALDRVYR = . if (VALDRVYR >= 81 )
replace VALYRFRQ = . if (VALYRFRQ >= 81 )
replace VAL30USE = . if (VAL30USE >= 81 )
replace VALCNODR = . if (VALCNODR >= 81 )
replace VALCTIME = . if (VALCTIME >= 81 )
replace VALDTIME = . if (VALDTIME >= 81 )
replace VMJUSEYR = . if (VMJUSEYR >= 81 )
replace VMJDRVYR = . if (VMJDRVYR >= 81 )
replace VMJALCYR = . if (VMJALCYR >= 81 )
replace VMJCOCYR = . if (VMJCOCYR >= 81 )
replace VMJHERYR = . if (VMJHERYR >= 81 )
replace VMJHALYR = . if (VMJHALYR >= 81 )
replace VMJINHYR = . if (VMJINHYR >= 81 )
replace VMJANLYR = . if (VMJANLYR >= 81 )
replace VMJTRNYR = . if (VMJTRNYR >= 81 )
replace VMJSTMYR = . if (VMJSTMYR >= 81 )
replace VMJSEDYR = . if (VMJSEDYR >= 81 )
replace VMJOTHYR = . if (VMJOTHYR >= 81 )
replace VMJYRS1 = . if (VMJYRS1 >= 9981 )
replace VMJYRS2 = . if (VMJYRS2 >= 9981 )
replace VMJYRS3 = . if (VMJYRS3 >= 9981 )
replace VMJYRS4 = . if (VMJYRS4 >= 9981 )
replace VMJYRS5 = . if (VMJYRS5 >= 9981 )
replace VMJ30USE = . if (VMJ30USE >= 81 )
replace VLTMJALC = . if (VLTMJALC >= 81 )
replace VLTMJAL1 = . if (VLTMJAL1 >= 9981 )
replace VLTMJAL2 = . if (VLTMJAL2 >= 9981 )
replace VLTMJAL3 = . if (VLTMJAL3 >= 9981 )
replace VLTMJAL4 = . if (VLTMJAL4 >= 9981 )
replace VLTMJAL5 = . if (VLTMJAL5 >= 9981 )
replace VLTMJFRM = . if (VLTMJFRM >= 81 )
replace VLTMJFRS = . if (VLTMJFRS >= 81 )
replace VLTMJTO = . if (VLTMJTO >= 81 )
replace VLTMJTOS = . if (VLTMJTOS >= 81 )
replace VLTMJHWY = . if (VLTMJHWY >= 81 )
replace VLTMJURB = . if (VLTMJURB >= 81 )
replace VLTMJWKD = . if (VLTMJWKD >= 81 )
replace VLTMJTIM = . if (VLTMJTIM >= 81 )
replace VLTMJABL = . if (VLTMJABL >= 81 )
replace VMJNOWAY = . if (VMJNOWAY >= 81 )
replace VMJNHIGH = . if (VMJNHIGH >= 81 )
replace VMJNPOLC = . if (VMJNPOLC >= 81 )
replace VMJNODVR = . if (VMJNODVR >= 81 )
replace VMJAPPT = . if (VMJAPPT >= 81 )
replace VMJOTHER = . if (VMJOTHER >= 81 )
replace VMJOTHSP = . if (VMJOTHSP >= 81 )
replace VMJSTOP = . if (VMJSTOP >= 81 )
replace VMJABIL = . if (VMJABIL >= 81 )
replace VCCUSEYR = . if (VCCUSEYR >= 81 )
replace VCCDRVYR = . if (VCCDRVYR >= 81 )
replace VCCALCYR = . if (VCCALCYR >= 81 )
replace VCCMRJYR = . if (VCCMRJYR >= 81 )
replace VCCHERYR = . if (VCCHERYR >= 81 )
replace VCCHALYR = . if (VCCHALYR >= 81 )
replace VCCINHYR = . if (VCCINHYR >= 81 )
replace VCCANLYR = . if (VCCANLYR >= 81 )
replace VCCTRNYR = . if (VCCTRNYR >= 81 )
replace VCCSTMYR = . if (VCCSTMYR >= 81 )
replace VCCSEDYR = . if (VCCSEDYR >= 81 )
replace VCCOTHYR = . if (VCCOTHYR >= 81 )
replace VCCYRS1 = . if (VCCYRS1 >= 9981 )
replace VCCYRS2 = . if (VCCYRS2 >= 9981 )
replace VCCYRS3 = . if (VCCYRS3 >= 9981 )
replace VCCYRS4 = . if (VCCYRS4 >= 9981 )
replace VCCYRS5 = . if (VCCYRS5 >= 9981 )
replace VCC30USE = . if (VCC30USE >= 81 )
replace VLTCCALC = . if (VLTCCALC >= 81 )
replace VLTCCAL1 = . if (VLTCCAL1 >= 9981 )
replace VLTCCAL2 = . if (VLTCCAL2 >= 9981 )
replace VLTCCAL3 = . if (VLTCCAL3 >= 9981 )
replace VLTCCAL4 = . if (VLTCCAL4 >= 9981 )
replace VLTCCAL5 = . if (VLTCCAL5 >= 9981 )
replace VLTCCFRM = . if (VLTCCFRM >= 81 )
replace VLTCCFRS = . if (VLTCCFRS >= 81 )
replace VLTCCTO = . if (VLTCCTO >= 81 )
replace VLTCCTOS = . if (VLTCCTOS >= 81 )
replace VLTCCHWY = . if (VLTCCHWY >= 81 )
replace VLTCCURB = . if (VLTCCURB >= 81 )
replace VLTCCWKD = . if (VLTCCWKD >= 81 )
replace VLTCCTIM = . if (VLTCCTIM >= 81 )
replace VLTCCABL = . if (VLTCCABL >= 81 )
replace VCCNOWAY = . if (VCCNOWAY >= 81 )
replace VCCNHIGH = . if (VCCNHIGH >= 81 )
replace VCCNPOLC = . if (VCCNPOLC >= 81 )
replace VCCNODVR = . if (VCCNODVR >= 81 )
replace VCCAPPT = . if (VCCAPPT >= 81 )
replace VCCOTHER = . if (VCCOTHER >= 81 )
replace VCCOTHSP = . if (VCCOTHSP >= 81 )
replace VCCSTOP = . if (VCCSTOP >= 81 )
replace VCCABIL = . if (VCCABIL >= 81 )
replace VTRUSEYR = . if (VTRUSEYR >= 81 )
replace VTRDRVYR = . if (VTRDRVYR >= 81 )
replace VTR30USE = . if (VTR30USE >= 81 )
replace VLTTRMED = . if (VLTTRMED >= 81 )
replace VLTTRALC = . if (VLTTRALC >= 81 )
replace VLTTRAL1 = . if (VLTTRAL1 >= 9981 )
replace VLTTRAL2 = . if (VLTTRAL2 >= 9981 )
replace VLTTRAL3 = . if (VLTTRAL3 >= 9981 )
replace VLTTRAL4 = . if (VLTTRAL4 >= 9981 )
replace VLTTRAL5 = . if (VLTTRAL5 >= 9981 )
replace VLTTRABL = . if (VLTTRABL >= 81 )
replace VSTUSEYR = . if (VSTUSEYR >= 81 )
replace VSTDRVYR = . if (VSTDRVYR >= 81 )
replace VST30USE = . if (VST30USE >= 81 )
replace VLTSTMED = . if (VLTSTMED >= 81 )
replace VLTSTALC = . if (VLTSTALC >= 81 )
replace VLTSTAL1 = . if (VLTSTAL1 >= 9981 )
replace VLTSTAL2 = . if (VLTSTAL2 >= 9981 )
replace VLTSTAL3 = . if (VLTSTAL3 >= 9981 )
replace VLTSTAL4 = . if (VLTSTAL4 >= 9981 )
replace VLTSTAL5 = . if (VLTSTAL5 >= 9981 )
replace VLTSTABL = . if (VLTSTABL >= 81 )
replace VSEUSEYR = . if (VSEUSEYR >= 81 )
replace VSEDRVYR = . if (VSEDRVYR >= 81 )
replace VSE30USE = . if (VSE30USE >= 81 )
replace VLTSEMED = . if (VLTSEMED >= 81 )
replace VLTSEALC = . if (VLTSEALC >= 81 )
replace VLTSEAL1 = . if (VLTSEAL1 >= 9981 )
replace VLTSEAL2 = . if (VLTSEAL2 >= 9981 )
replace VLTSEAL3 = . if (VLTSEAL3 >= 9981 )
replace VLTSEAL4 = . if (VLTSEAL4 >= 9981 )
replace VLTSEAL5 = . if (VLTSEAL5 >= 9981 )
replace VLTSEABL = . if (VLTSEABL >= 81 )
replace SKPWKST3 = . if (SKPWKST3 >= 81 )
replace WORKDAYS = . if (WORKDAYS >= 81 )
replace WORKBLAH = . if (WORKBLAH >= 81 )
replace SKPPREG = . if (SKPPREG == 9)
replace PREGNANT = . if (PREGNANT >= 81 )
replace PREGMOS = . if (PREGMOS >= 81 )
replace TOTPEOP = . if (TOTPEOP >= 81 )
replace SKPMHC = . if (SKPMHC == 9)
replace DEPRESS = . if (DEPRESS >= 81 )
replace DEPDAYS = . if (DEPDAYS >= 81 )
replace DEPFREQ = . if (DEPFREQ >= 81 )
replace LOSTINT1 = . if (LOSTINT1 >= 81 )
replace TIRED1 = . if (TIRED1 >= 81 )
replace WTCHNG1 = . if (WTCHNG1 >= 81 )
replace LBSCHNG1 = . if (LBSCHNG1 >= 981 )
replace SLPLOSS1 = . if (SLPLOSS1 >= 81 )
replace SLPFREQ1 = . if (SLPFREQ1 >= 81 )
replace CONCEN1 = . if (CONCEN1 >= 81 )
replace DOWN1 = . if (DOWN1 >= 81 )
replace IDEAT1 = . if (IDEAT1 >= 81 )
replace SKPDEP1 = . if (SKPDEP1 >= 81 )
replace DEPWKS1 = . if (DEPWKS1 >= 81 )
replace DEPMO1 = . if (DEPMO1 >= 81 )
replace DEPYR1 = . if (DEPYR1 >= 981 )
replace LOSTINT2 = . if (LOSTINT2 >= 81 )
replace LOSINDAY = . if (LOSINDAY >= 81 )
replace LOSINFRQ = . if (LOSINFRQ >= 81 )
replace TIRED2 = . if (TIRED2 >= 81 )
replace WTCHNG2 = . if (WTCHNG2 >= 81 )
replace LBSCHNG2 = . if (LBSCHNG2 >= 981 )
replace SLPLOSS2 = . if (SLPLOSS2 >= 81 )
replace SLPFREQ2 = . if (SLPFREQ2 >= 81 )
replace CONCEN2 = . if (CONCEN2 >= 81 )
replace DOWN2 = . if (DOWN2 >= 81 )
replace IDEAT2 = . if (IDEAT2 >= 81 )
replace SKPDEP2 = . if (SKPDEP2 >= 81 )
replace DEPWKS2 = . if (DEPWKS2 >= 81 )
replace DEPMO2 = . if (DEPMO2 >= 81 )
replace DEPYR2 = . if (DEPYR2 >= 981 )
replace WORRIED = . if (WORRIED >= 81 )
replace WOREND = . if (WOREND >= 81 )
replace WORNOMO1 = . if (WORNOMO1 >= 9981 )
replace WORHAPN1 = . if (WORHAPN1 >= 81 )
replace WORSERI1 = . if (WORSERI1 >= 81 )
replace WORDIFF1 = . if (WORDIFF1 >= 81 )
replace WORNOMO2 = . if (WORNOMO2 >= 9981 )
replace WORHAPN2 = . if (WORHAPN2 >= 81 )
replace WORSERI2 = . if (WORSERI2 >= 81 )
replace WORDIFF2 = . if (WORDIFF2 >= 81 )
replace SKPWOR = . if (SKPWOR >= 81 )
replace WORREST = . if (WORREST >= 81 )
replace WOREDGE = . if (WOREDGE >= 81 )
replace WORIRRIT = . if (WORIRRIT >= 81 )
replace WORHEART = . if (WORHEART >= 81 )
replace WORTIRED = . if (WORTIRED >= 81 )
replace WORSLEEP = . if (WORSLEEP >= 81 )
replace WORFAINT = . if (WORFAINT >= 81 )
replace FEARPUB = . if (FEARPUB >= 81 )
replace FEAROUT = . if (FEAROUT >= 81 )
replace FEARBRDG = . if (FEARBRDG >= 81 )
replace SKPFEAR1 = . if (SKPFEAR1 >= 81 )
replace FEAROFT = . if (FEAROFT >= 81 )
replace FEARYRS = . if (FEARYRS >= 81 )
replace FEARMOS = . if (FEARMOS >= 81 )
replace FEARFANT = . if (FEARFANT >= 81 )
replace FEARTRAP = . if (FEARTRAP >= 81 )
replace FEARHELP = . if (FEARHELP >= 81 )
replace PANIC1 = . if (PANIC1 >= 81 )
replace PANIC2 = . if (PANIC2 >= 81 )
replace PANICNUM = . if (PANICNUM >= 981 )
replace PANICMO = . if (PANICMO >= 81 )
replace PANICYR = . if (PANICYR >= 981 )
replace PANIDANG = . if (PANIDANG >= 81 )
replace SKPFEAR2 = . if (SKPFEAR2 >= 81 )
replace PANIFEAR = . if (PANIFEAR >= 81 )
replace PANINOFR = . if (PANINOFR >= 81 )
replace PANIHART = . if (PANIHART >= 81 )
replace PANIPAIN = . if (PANIPAIN >= 81 )
replace PANISWET = . if (PANISWET >= 81 )
replace PANISHAK = . if (PANISHAK >= 81 )
replace PANIHOT = . if (PANIHOT >= 81 )
replace PANIUNRL = . if (PANIUNRL >= 81 )
replace NUERTMT = . if (NUERTMT >= 81 )
replace NUHSPOV = . if (NUHSPOV >= 81 )
replace NUHSPPE = . if (NUHSPPE >= 81 )
replace OUTPTPE = . if (OUTPTPE >= 81 )
replace PROXABLE = . if (PROXABLE >= 81 )
replace PROXYREL = . if (PROXYREL >= 981 )
replace PROXHOME = . if (PROXHOME >= 81 )
replace PROXJOIN = . if (PROXJOIN >= 81 )
replace CAREUSU = . if (CAREUSU >= 81 )
replace NCARERSN = . if (NCARERSN >= 81 )
replace NCRRSNSP = . if (NCRRSNSP >= 81 )
replace NCRRSNSC = . if (NCRRSNSC >= 81 )
replace CAREOFT = . if (CAREOFT >= 81 )
replace PYRCARE = . if (PYRCARE >= 81 )
replace PYRCRTYP = . if (PYRCRTYP >= 81 )
replace PYRCRTSP = . if (PYRCRTSP >= 81 )
replace PYRCRTSC = . if (PYRCRTSC >= 81 )
replace CARENOW = . if (CARENOW >= 81 )
replace MNRSNNCR = . if (MNRSNNCR >= 81 )
replace MNRSNNSP = . if (MNRSNNSP >= 81 )
replace MNRSNNSC = . if (MNRSNNSC >= 81 )
replace UCARETYP = . if (UCARETYP >= 81 )
replace UCRTYPSP = . if (UCRTYPSP >= 81 )
replace UCRTYPSC = . if (UCRTYPSC >= 81 )
replace MEDICARE = . if (MEDICARE >= 81 )
replace MEDICAID = . if (MEDICAID >= 81 )
replace CHAMPUS = . if (CHAMPUS >= 81 )
replace PRVHLTIN = . if (PRVHLTIN >= 81 )
replace GRPHLTIN = . if (GRPHLTIN >= 81 )
replace PDHINPRM = . if (PDHINPRM >= 81 )
replace HLTINALC = . if (HLTINALC >= 81 )
replace HLTINDRG = . if (HLTINDRG >= 81 )
replace HLTINMNT = . if (HLTINMNT >= 81 )
replace SOC1 = . if (SOC1 >= 81 )
replace SOC2 = . if (SOC2 >= 81 )
replace SSI1 = . if (SSI1 >= 81 )
replace SSI2 = . if (SSI2 >= 81 )
replace PUB1 = . if (PUB1 >= 81 )
replace PUB2 = . if (PUB2 >= 81 )
replace AFDC = . if (AFDC >= 81 )
replace INT1 = . if (INT1 >= 81 )
replace INT2 = . if (INT2 >= 81 )
replace CHD1 = . if (CHD1 >= 81 )
replace CHD2 = . if (CHD2 >= 81 )
replace OTH1 = . if (OTH1 >= 81 )
replace OTH2 = . if (OTH2 >= 81 )
replace FSTAMP = . if (FSTAMP >= 81 )
replace PINC1 = . if (PINC1 >= 81 )
replace SKPTFMIN = . if (SKPTFMIN >= 81 )
replace FINC1 = . if (FINC1 >= 81 )
replace TELNO = . if (TELNO >= 81 )
replace IRPINSUR = . if (IRPINSUR == 9)
replace IIPINSUR = . if (IIPINSUR == 9)
replace IRINSUR = . if (IRINSUR == 9)
replace IIINSUR = . if (IIINSUR == 9)
replace IRSOC1 = . if (IRSOC1 == 9)
replace IISOC1 = . if (IISOC1 == 9)
replace IRSSI1 = . if (IRSSI1 == 9)
replace IISSI1 = . if (IISSI1 == 9)
replace IRPUB1 = . if (IRPUB1 == 9)
replace IIPUB1 = . if (IIPUB1 == 9)
replace IRAFDC = . if (IRAFDC == 9)
replace IIAFDC = . if (IIAFDC == 9)
replace IRINT1 = . if (IRINT1 == 9)
replace IIINT1 = . if (IIINT1 == 9)
replace IRCHD1 = . if (IRCHD1 == 9)
replace IICHD1 = . if (IICHD1 == 9)
replace IROTH1 = . if (IROTH1 == 9)
replace IIOTH1 = . if (IIOTH1 == 9)
replace IRFSTAMP = . if (IRFSTAMP == 9)
replace IIFSTAMP = . if (IIFSTAMP == 9)
replace IRPINC1 = . if (IRPINC1 == 9)
replace IIPINC1 = . if (IIPINC1 == 9)
replace IRFINC1 = . if (IRFINC1 == 9)
replace IIFINC1 = . if (IIFINC1 == 9)
replace IRSOC2 = . if (IRSOC2 == 9)
replace IISOC2 = . if (IISOC2 == 9)
replace IRSSI2 = . if (IRSSI2 == 9)
replace IISSI2 = . if (IISSI2 == 9)
replace IRPUB2 = . if (IRPUB2 == 9)
replace IIPUB2 = . if (IIPUB2 == 9)
replace IRINT2 = . if (IRINT2 == 9)
replace IIINT2 = . if (IIINT2 == 9)
replace IRCHD2 = . if (IRCHD2 == 9)
replace IICHD2 = . if (IICHD2 == 9)
replace IROTH2 = . if (IROTH2 == 9)
replace IIOTH2 = . if (IIOTH2 == 9)
replace IRPEOP = . if (IRPEOP >= 81 )
replace PARSTAT = . if (PARSTAT == 9)
replace FEMBABY = . if (FEMBABY == 9)
replace FEMKIDS = . if (FEMKIDS == 9)
replace MALEBABY = . if (MALEBABY == 9)
replace MALEKIDS = . if (MALEKIDS == 9)
replace F15_44 = . if (F15_44 == 9)
replace M15_44 = . if (M15_44 == 9)
replace PREG = . if (PREG == 9)
replace PREG2 = . if (PREG2 == 9)
replace TRIMEST = . if (TRIMEST == 9)
replace INDCAT = . if (INDCAT >= 81 )
replace PERINC = . if (PERINC == 9)
replace PERINC2 = . if (PERINC2 == 9)
replace PERINC3 = . if (PERINC3 == 9)
replace TOTCAT = . if (TOTCAT >= 81 )
replace FAMINC = . if (FAMINC == 9)
replace FAMINC2 = . if (FAMINC2 == 9)
replace FAMINC3 = . if (FAMINC3 == 9)
replace WELFARE = . if (WELFARE == 9)
replace NEEDLREC = . if (NEEDLREC >= 81 )
replace NEDFLAG4 = . if (NEDFLAG4 == 9)
replace NEDYR4 = . if (NEDYR4 == 9)
replace WITHDRW = . if (WITHDRW >= 81 )
replace SOMCOM = . if (SOMCOM >= 81 )
replace ANXDEP = . if (ANXDEP >= 81 )
replace SOCPROB = . if (SOCPROB >= 81 )
replace THPROB = . if (THPROB >= 81 )
replace ATTPROB = . if (ATTPROB >= 81 )
replace DELBEH = . if (DELBEH >= 81 )
replace AGGBEH = . if (AGGBEH >= 81 )
replace WITHDRWT = . if (WITHDRWT >= 981 )
replace SOMCOMT = . if (SOMCOMT >= 981 )
replace ANXDEPT = . if (ANXDEPT >= 981 )
replace SOCPROBT = . if (SOCPROBT >= 981 )
replace THPROBT = . if (THPROBT >= 981 )
replace ATTPROBT = . if (ATTPROBT >= 981 )
replace DELBEHT = . if (DELBEHT >= 981 )
replace AGGBEHT = . if (AGGBEHT >= 981 )
replace SXHIVLF = . if (SXHIVLF >= 81 )
replace SXHIVYR = . if (SXHIVYR >= 81 )
replace SXREL = . if (SXREL >= 81 )
replace SXRELMAR = . if (SXRELMAR >= 81 )
replace SXCONDYR = . if (SXCONDYR >= 81 )
replace SXRSKANY = . if (SXRSKANY >= 81 )
replace SXRSKCNT = . if (SXRSKCNT >= 81 )
replace SXDRANY = . if (SXDRANY >= 81 )
replace SXDRCNT = . if (SXDRCNT >= 81 )
replace MDESFS1 = . if (MDESFS1 >= 81 )
replace MDESFS3 = . if (MDESFS3 >= 81 )
replace PROBMDE1 = . if (PROBMDE1 >= 81.0000 )
replace PROBMDE3 = . if (PROBMDE3 >= 81.0000 )
replace MDE1 = . if (MDE1 >= 81 )
replace MDE3 = . if (MDE3 >= 81 )
replace GADSFS1 = . if (GADSFS1 >= 81 )
replace GADSFS3 = . if (GADSFS3 >= 81 )
replace PROBGAD1 = . if (PROBGAD1 >= 81.0000 )
replace PROBGAD3 = . if (PROBGAD3 >= 81.0000 )
replace GAD1 = . if (GAD1 >= 81 )
replace GAD3 = . if (GAD3 >= 81 )
replace AGPSFS1 = . if (AGPSFS1 >= 81 )
replace AGPSFS3 = . if (AGPSFS3 >= 81 )
replace PROBAGP1 = . if (PROBAGP1 >= 81 )
replace PROBAGP3 = . if (PROBAGP3 >= 81 )
replace AGP1 = . if (AGP1 >= 81 )
replace AGP3 = . if (AGP3 >= 81 )
replace PASFS1 = . if (PASFS1 >= 81 )
replace PASFS3 = . if (PASFS3 >= 81 )
replace PROBPA1 = . if (PROBPA1 >= 81.0000 )
replace PROBPA3 = . if (PROBPA3 >= 81.0000 )
replace PA1 = . if (PA1 >= 81 )
replace PA3 = . if (PA3 >= 81 )
replace BHOUR = . if (BHOUR == 98)
replace BMIN = . if (BMIN == 98)
replace BAP = . if (BAP == 98)
replace EAP = . if (EAP == 98)
replace LANGVER = . if (LANGVER == 9)
replace UNDINT = . if (UNDINT >= 81 )
replace COOPINT = . if (COOPINT >= 81 )
replace PRIVACY = . if (PRIVACY >= 81 )
replace PPRES = . if (PPRES >= 81 )
replace SPRES = . if (SPRES >= 81 )
replace PARPRES = . if (PARPRES >= 81 )
replace OARPRES = . if (OARPRES >= 81 )
replace OAPRES = . if (OAPRES >= 81 )
replace CPRES = . if (CPRES >= 81 )
replace OPRESNSP = . if (OPRESNSP >= 81 )
replace OPRESSPA = . if (OPRESSPA >= 981 )
replace OPRESSPB = . if (OPRESSPB >= 981 )
replace WHOMARKD = . if (WHOMARKD >= 81 )
replace QUARTER = . if (QUARTER == 9)
replace FAMSKIP = . if (FAMSKIP == 9)
replace GQTYPE = . if (GQTYPE == 9)
replace PDEN = . if (PDEN == 9)
replace PDEN2 = . if (PDEN2 == 9)
replace REGION = . if (REGION == 9)
replace DIVISION = . if (DIVISION == 9)
replace RURORURB = . if (RURORURB == 9)
replace RELINTHH = . if (RELINTHH >= 81 )
replace MJTOT3 = . if (MJTOT3 >= 81 )
replace COCTOT3 = . if (COCTOT3 >= 81 )
replace ALCDAYS2 = . if (ALCDAYS2 == 6)
replace MJDY30A3 = . if (MJDY30A3 == 6)
replace ALCDAYS3 = . if (ALCDAYS3 == 6)
replace AVCIG2 = . if (AVCIG2 == 4)
replace NOTMARJ = . if (NOTMARJ == 9)
replace RACESEX2 = . if (RACESEX2 == 9)
replace CIGTRY2 = . if (CIGTRY2 >= 81 )
replace ALCTRY2 = . if (ALCTRY2 >= 81 )
replace MJAGE2 = . if (MJAGE2 >= 81 )
replace INHAGE2 = . if (INHAGE2 >= 81 )
replace COCAGE2 = . if (COCAGE2 >= 81 )
replace HALLAGE2 = . if (HALLAGE2 >= 81 )
replace HERAGE2 = . if (HERAGE2 >= 81 )
replace STIMAGE2 = . if (STIMAGE2 >= 81 )
replace SEDAGE2 = . if (SEDAGE2 >= 81 )
replace TRANAGE2 = . if (TRANAGE2 >= 81 )
replace ANALAGE2 = . if (ANALAGE2 >= 81 )
replace ALCONLYL = . if (ALCONLYL == 9)
replace ALCONLYY = . if (ALCONLYY == 9)
replace ALCONLYM = . if (ALCONLYM == 9)
replace ILLONLYL = . if (ILLONLYL == 9)
replace ILLONLYY = . if (ILLONLYY == 9)
replace ILLONLYM = . if (ILLONLYM == 9)
replace MRJONLYL = . if (MRJONLYL == 9)
replace MRJONLYY = . if (MRJONLYY == 9)
replace MRJONLYM = . if (MRJONLYM == 9)
replace PSYONLYL = . if (PSYONLYL == 9)
replace PSYONLYY = . if (PSYONLYY == 9)
replace PSYONLYM = . if (PSYONLYM == 9)
replace OTHONLYL = . if (OTHONLYL == 9)
replace OTHONLYY = . if (OTHONLYY == 9)
replace OTHONLYM = . if (OTHONLYM == 9)
replace ALCILLL = . if (ALCILLL == 9)
replace ALCILLY = . if (ALCILLY == 9)
replace ALCILLM = . if (ALCILLM == 9)
replace ALCMRJL = . if (ALCMRJL == 9)
replace ALCMRJY = . if (ALCMRJY == 9)
replace ALCMRJM = . if (ALCMRJM == 9)
replace ALCPSYL = . if (ALCPSYL == 9)
replace ALCPSYY = . if (ALCPSYY == 9)
replace ALCPSYM = . if (ALCPSYM == 9)
replace ALCOTHL = . if (ALCOTHL == 9)
replace ALCOTHY = . if (ALCOTHY == 9)
replace ALCOTHM = . if (ALCOTHM == 9)
replace SUB1LIF = . if (SUB1LIF == 9)
replace SUB2LIF = . if (SUB2LIF == 9)
replace SUB3LIF = . if (SUB3LIF == 9)
replace SUB1YR = . if (SUB1YR == 9)
replace SUB2YR = . if (SUB2YR == 9)
replace SUB3YR = . if (SUB3YR == 9)
replace SUB1MON = . if (SUB1MON == 9)
replace SUB2MON = . if (SUB2MON == 9)
replace SUB3MON = . if (SUB3MON == 9)
replace PSYAGE = . if (PSYAGE >= 81 )
replace FERTAGE = . if (FERTAGE >= 81 )
replace PREG3 = . if (PREG3 >= 81 )
replace TRIMEST2 = . if (TRIMEST2 >= 81 )
replace RSKCIG = . if (RSKCIG >= 81 )
replace RSKMJ1 = . if (RSKMJ1 >= 81 )
replace RSKMJ2 = . if (RSKMJ2 >= 81 )
replace RSKCOC1 = . if (RSKCOC1 >= 81 )
replace RSKCOC2 = . if (RSKCOC2 >= 81 )
replace RSKALC1 = . if (RSKALC1 >= 81 )
replace RSKALC2 = . if (RSKALC2 >= 81 )
replace TOTPROB = . if (TOTPROB >= 981.0000 )
replace INT = . if (INT >= 81.0000 )
replace EXT = . if (EXT >= 81 )
replace PR_EMOT = . if (PR_EMOT >= 81 )
replace PR_BEHAV = . if (PR_BEHAV >= 81 )
replace PR_TOTAL = . if (PR_TOTAL >= 81 )
replace PR_WD = . if (PR_WD >= 81 )
replace PR_SC = . if (PR_SC >= 81 )
replace PR_AD = . if (PR_AD >= 81 )
replace PR_SP = . if (PR_SP >= 81 )
replace PR_TP = . if (PR_TP >= 81 )
replace PR_AP = . if (PR_AP >= 81 )
replace PR_DB = . if (PR_DB >= 81 )
replace PR_AB = . if (PR_AB >= 81 )
replace ANY4MENT = . if (ANY4MENT >= 81 )
replace AGECAT3 = . if (AGECAT3 >= 81 )
replace DRUNKYR3 = . if (DRUNKYR3 >= 81 )
replace SEXYR = . if (SEXYR >= 81 )
replace RELNOW = . if (RELNOW >= 81 )
replace HIVTEST = . if (HIVTEST >= 81 )
replace CDALWAYS = . if (CDALWAYS >= 81 )
replace CDSOME = . if (CDSOME >= 81 )
replace CDNEVER = . if (CDNEVER >= 81 )
replace YRDIFPP1 = . if (YRDIFPP1 >= 81 )
replace YRDIFPP2 = . if (YRDIFPP2 >= 81 )
replace EHOUR = . if (EHOUR >= 81 )
replace EMIN = . if (EMIN >= 81 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

